using System;
using System.Collections;
using System.Data;
using System.Data.Common;
using Vevo;
using Vevo.Shared.Utilities;

namespace Vevo.Shared.DataAccess.Tester
{
    internal class DataAccess
    {
        public DataAccess( string connectionString, string providerName )
        {
            _connectionString = connectionString;
            _providerName = providerName;
            _dbFactory = DbProviderFactories.GetFactory( _providerName );
        }

        #region Private
        private string _connectionString;
        private string _providerName;
        private DbProviderFactory _dbFactory;


        private DbCommand CreateCommand()
        {
            DbConnection conn = _dbFactory.CreateConnection();
            conn.ConnectionString = _connectionString;
            return conn.CreateCommand();
        }

        private DbCommand[] SplitBatchCommand(
            DbCommand command,
            DbParameter[] parameters )
        {
            string mainText = command.CommandText;

            ArrayList commands = new ArrayList();
            string[] textList = mainText.Split( ';' );

            int currentParameter = 0;
            for (int i = 0; i < textList.Length; i++)
            {
                if (textList[i].Trim() != "")
                {
                    DbCommand newCommand = command.Connection.CreateCommand();
                    newCommand.Connection = command.Connection;
                    newCommand.CommandType = command.CommandType;
                    newCommand.CommandText = textList[i] + ";";

                    int numParams = GetNumberOfParameters( textList[i] );
                    for (int j = 0;
                         j < numParams;
                         j++)
                    {
                        newCommand.Parameters.Add( parameters[currentParameter] );
                        currentParameter++;
                    }

                    commands.Add( newCommand );
                }
            }
            DbCommand[] results = new DbCommand[commands.Count];
            commands.CopyTo( results );

            return results;
        }

        private int GetNumberOfParameters( string sql )
        {
            int numSymbol = StringUtilities.CountOccurrencesInString( sql, '@' );
            int numNonVar = StringUtilities.CountOccurrencesInString( sql, "@@" );
            return numSymbol - (2 * numNonVar);
        }
        #endregion


        public DbCommand CreateStoredProcedureCommand()
        {
            DbCommand comm = CreateCommand();
            comm.CommandType = CommandType.StoredProcedure;
            return comm;
        }

        public DbCommand CreateTextCommand()
        {
            return CreateCommand();
        }

        public DbParameter CreateParameterBool( bool value )
        {
            DbParameter param = _dbFactory.CreateParameter();
            param.DbType = DbType.Boolean;
            param.Value = value;
            return param;
        }

        public DbParameter CreateParameterInt32( int value )
        {
            DbParameter param = _dbFactory.CreateParameter();
            param.DbType = DbType.Int32;
            param.Value = value;
            return param;
        }

        public DbParameter CreateParameterDecimal( decimal value )
        {
            DbParameter param = _dbFactory.CreateParameter();
            param.DbType = DbType.Decimal;
            param.Value = value;
            return param;
        }

        public DbParameter CreateParameterString( string value )
        {
            DbParameter param = _dbFactory.CreateParameter();
            param.DbType = DbType.String;
            param.Value = value;
            return param;
        }

        public DbParameter CreateParameterString( string value, int size )
        {
            DbParameter param = CreateParameterString( value );
            param.Size = size;
            return param;
        }

        public DataTable ExecuteSelect( string sqlString )
        {
            DbCommand command = CreateTextCommand();
            command.CommandText = sqlString;
            return ExecuteSelect( command );
        }

        public DataTable ExecuteSelect(
            string sqlString,
            params DbParameter[] parameters )
        {
            DbCommand command = CreateTextCommand();
            command.CommandText = sqlString;
            return ExecuteSelect( command, parameters );
        }

        public DataTable ExecuteSelect( DbCommand command )
        {
            return ExecuteSelect( command, null );
        }

        public DataTable ExecuteSelect(
            DbCommand command,
            params DbParameter[] parameters )
        {
            DataTable table;
            try
            {
                // Jet data provider only supports one SQL command at a time.
                // Need to separate execution for Jet.
                DbCommand[] commandList = SplitBatchCommand( command, parameters );

                DbDataReader reader = null;
                command.Connection.Open();
                foreach (DbCommand current in commandList)
                    reader = current.ExecuteReader();

                // Only return result from the last query
                table = new DataTable();
                table.Load( reader );
                reader.Close();
            }
            finally
            {
                command.Connection.Close();
            }
            return table;
        }

        public int ExecuteNonQuery( string sqlString )
        {
            DbCommand command = CreateTextCommand();
            command.CommandText = sqlString;
            return ExecuteNonQuery( command );
        }

        public int ExecuteNonQuery(
            string sqlString,
            params DbParameter[] parameters )
        {
            DbCommand command = CreateTextCommand();
            command.CommandText = sqlString;
            return ExecuteNonQuery( command, parameters );
        }

        public int ExecuteNonQuery( DbCommand command )
        {
            return ExecuteNonQuery( command, null );
        }

        public int ExecuteNonQuery(
            DbCommand command,
            params DbParameter[] parameters )
        {
            int affectedRows = -1;
            try
            {
                // Jet data provider only supports one SQL command at a time.
                // Need to separate execution for Jet.
                DbCommand[] commandList = SplitBatchCommand( command, parameters );

                command.Connection.Open();
                foreach (DbCommand current in commandList)
                    affectedRows = current.ExecuteNonQuery();
            }
            finally
            {
                command.Connection.Close();
            }
            return affectedRows;
        }


    }
}
