using System;
using System.Collections;
using System.Collections.Generic;
using System.Data;
using System.Text;

using Vevo.Base.Data.Caching;
using Vevo.Domain;
using Vevo.Domain.Tax;
using Vevo.Domain.DataInterfaces;
using Vevo.Shared.DataAccess;
using Vevo.Shared.DataAccess.Implementation;
using Vevo.Base.Data.Implementation;
using Vevo.Base.Data;
using Vevo.Base.Domain;

namespace Vevo.Data.Implementation
{
    internal class TaxClassRuleAccess : BaseListedDataAccess<string, TaxClassRule>
    {
        #region Private

        private const string AllTaxClassRuleField =
            "TaxClassRuleID, TaxClassID, CountryCode, StateCode, ZipCode, " +
            "TaxRate, IsDefaultCountry, IsDefaultState, IsDefaultZip ";

        private TaxClassRule CreateOneTaxClassRuleFromRow( DataRow row )
        {
            TaxClassRule taxClassRule = new TaxClassRule();
            taxClassRule.TaxClassRuleID = row["TaxClassRuleID"].ToString();
            taxClassRule.TaxClassID = row["TaxClassID"].ToString();
            taxClassRule.CountryCode = row["CountryCode"].ToString();
            taxClassRule.StateCode = row["StateCode"].ToString();
            taxClassRule.ZipCode = row["ZipCode"].ToString();
            taxClassRule.TaxRate = Convert.ToDecimal( row["TaxRate"] );
            taxClassRule.IsDefaultCountry = Convert.ToBoolean( row["IsDefaultCountry"] );
            taxClassRule.IsDefaultState = Convert.ToBoolean( row["IsDefaultState"] );
            taxClassRule.IsDefaultZip = Convert.ToBoolean( row["IsDefaultZip"] );

            return taxClassRule;
        }

        private IList<TaxClassRule> ConvertTaxClassRuleTableToList( DataTable table )
        {
            return ConvertTaxClassRuleTableToList( table, 0, table.Rows.Count );
        }

        private IList<TaxClassRule> ConvertTaxClassRuleTableToList( DataTable table, int startIndex, int endIndex )
        {
            IList<TaxClassRule> list = new List<TaxClassRule>();

            for (int i = startIndex; i <= endIndex && i < table.Rows.Count; i++)
                list.Add( CreateOneTaxClassRuleFromRow( table.Rows[i] ) );

            return list;
        }

        private string CreateSortByText( string sortBy )
        {
            if (!String.IsNullOrEmpty( sortBy ))
                sortBy += ",";

            if (sortBy.Contains( "CountryCode" ))
            {
                sortBy +=
                    " IsDefaultCountry " + DbImplementation.Sql.CreateFalseToTrueBoolSortText() + ", " +
                    "IsDefaultState " + DbImplementation.Sql.CreateFalseToTrueBoolSortText() + ", " +
                    "StateCode, " +
                    "IsDefaultZip " + DbImplementation.Sql.CreateFalseToTrueBoolSortText() + ", " +
                    "ZipCode";
            }
            else if (sortBy.Contains( "StateCode" ))
            {
                sortBy +=
                 " IsDefaultCountry " + DbImplementation.Sql.CreateFalseToTrueBoolSortText() + ", " +
                 "CountryCode, " +
                 "IsDefaultState " + DbImplementation.Sql.CreateFalseToTrueBoolSortText() + ", " +
                 "IsDefaultZip " + DbImplementation.Sql.CreateFalseToTrueBoolSortText() + ", " +
                 "ZipCode";
            }
            else if (sortBy.Contains( "ZipCode" ))
            {
                sortBy +=
                 " IsDefaultCountry " + DbImplementation.Sql.CreateFalseToTrueBoolSortText() + ", " +
                 "CountryCode, " +
                 "IsDefaultState " + DbImplementation.Sql.CreateFalseToTrueBoolSortText() + ", " +
                 "StateCode, " +
                 "IsDefaultZip " + DbImplementation.Sql.CreateFalseToTrueBoolSortText();
            }
            else
            {
                sortBy +=
                    " IsDefaultCountry " + DbImplementation.Sql.CreateFalseToTrueBoolSortText() + ", " +
                    "CountryCode, " +
                    "IsDefaultState " + DbImplementation.Sql.CreateFalseToTrueBoolSortText() + ", " +
                    "StateCode, " +
                    "IsDefaultZip " + DbImplementation.Sql.CreateFalseToTrueBoolSortText() + ", " +
                    "ZipCode";
            }

            return String.Format( " ORDER BY {0} ", sortBy );
        }

        #endregion

        #region Protected

        protected override void Create( string taxClassID, TaxClassRule taxClassRule )
        {
            taxClassRule.TaxClassRuleID = DataAccess.ExecuteScalar(
                "INSERT INTO TaxClassRule( TaxClassID, CountryCode, StateCode, ZipCode, TaxRate, " +
                "IsDefaultCountry, IsDefaultState, IsDefaultZip ) " +
                "VALUES (@TaxClassID, @CountryCode, @StateCode, @ZipCode, @TaxRate, " +
                "@IsDefaultCountry, @IsDefaultState, @IsDefaulteZip ); " +
                "SELECT @@Identity",
                DataAccess.CreateParameterString( taxClassID ),
                DataAccess.CreateParameterString( taxClassRule.CountryCode ),
                DataAccess.CreateParameterString( taxClassRule.StateCode ),
                DataAccess.CreateParameterString( taxClassRule.ZipCode ),
                DataAccess.CreateParameterDecimal( taxClassRule.TaxRate ),
                DataAccess.CreateParameterBool( taxClassRule.IsDefaultCountry ),
                DataAccess.CreateParameterBool( taxClassRule.IsDefaultState ),
                DataAccess.CreateParameterBool( taxClassRule.IsDefaultZip )
            );

            taxClassRule.TaxClassID = taxClassID;
        }

        protected override void Update( string taxClassID, TaxClassRule taxClassRule )
        {
            DataAccess.ExecuteSelect(
                "UPDATE TaxClassRule " +
                "SET " +
                "   TaxClassID = @TaxClassID, " +
                "   CountryCode = @CountryCode, " +
                "   StateCode = @StateCode, " +
                "   ZipCode = @ZipCode, " +
                "   TaxRate = @TaxRate, " +
                "   IsDefaultCountry = @IsDefaultCountry, " +
                "   IsDefaultState = @IsDefaultState, " +
                "   IsDefaultZip = @IsDefaultZip " +
                "WHERE TaxClassRuleID = @TaxClassRuleID; ",
                DataAccess.CreateParameterString( taxClassRule.TaxClassID ),
                DataAccess.CreateParameterString( taxClassRule.CountryCode ),
                DataAccess.CreateParameterString( taxClassRule.StateCode ),
                DataAccess.CreateParameterString( taxClassRule.ZipCode ),
                DataAccess.CreateParameterDecimal( taxClassRule.TaxRate ),
                DataAccess.CreateParameterBool( taxClassRule.IsDefaultCountry ),
                DataAccess.CreateParameterBool( taxClassRule.IsDefaultState ),
                DataAccess.CreateParameterBool( taxClassRule.IsDefaultZip ),
                DataAccess.CreateParameterString( taxClassRule.TaxClassRuleID )
            );
        }

        protected override void Delete( string taxClassRuleID, TaxClassRule taxClassRule )
        {
            DataAccess.ExecuteNonQuery(
                "DELETE " +
                "FROM TaxClassRule " +
                "WHERE TaxClassRuleID = @TaxClassRuleID; ",
                DataAccess.CreateParameterString( taxClassRule.TaxClassRuleID ) );
        }

        #endregion

        #region Public Methods

        public void DeleteByTaxClassID( string taxClassID )
        {
            DataAccess.ExecuteNonQuery(
                "DELETE " +
                "FROM TaxClassRule " +
                "WHERE TaxClassID = @TaxClassID; ",
                DataAccess.CreateParameterString( taxClassID ) );
        }

        public TaxClassRule GetOne( string taxClassRuleID )
        {
            DataTable table = DataAccess.ExecuteSelect(
                "SELECT " + AllTaxClassRuleField +
                "FROM TaxClassRule " +
                "WHERE TaxClassRuleID = @TaxClassRuleID; ",
                DataAccess.CreateParameterString( taxClassRuleID ) );

            if (table.Rows.Count > 0)
                return CreateOneTaxClassRuleFromRow( table.Rows[0] );
            else
                return TaxClassRule.Null;
        }

        public IList<TaxClassRule> GetAll( string sortBy )
        {
            DataTable table = DataAccess.ExecuteSelect(
                "SELECT " + AllTaxClassRuleField +
                "FROM TaxClassRule" +
                CreateSortByText( sortBy ) + "; "
            );

            return ConvertTaxClassRuleTableToList( table );
        }

        public IList<TaxClassRule> GetByTaxClassID( string taxClassID )
        {
            DataTable table = DataAccess.ExecuteSelect(
                "SELECT " + AllTaxClassRuleField +
                "FROM TaxClassRule " +
                "WHERE TaxClassID = @TaxClassID; ",
                DataAccess.CreateParameterString( taxClassID ) );

            return ConvertTaxClassRuleTableToList( table );
        }

        public IList<TaxClassRule> SearchTaxClassRules(
            string taxClassID,
            string sortBy,
            SearchFilter searchFilter,
            int startIndex,
            int endIndex,
            out int howManyItems )
        {
            ArrayList parameterList = new ArrayList();
            SearchFilterHelperNew searchFilterHelper = new SearchFilterHelperNew();
            string commandSearch = searchFilterHelper.CreateCommandWithWhere( searchFilter, searchFilter.FieldName, parameterList );
            parameterList.Add( DataAccess.CreateParameterString( taxClassID ) );

            DataTable table = DataAccess.ExecuteSelect(
                "SELECT " + AllTaxClassRuleField +
                "FROM TaxClassRule " +
                commandSearch +
                " AND TaxClassID = @TaxClassID " +
                CreateSortByText( sortBy ) + "; ",
                DataAccess.ConvertArrayListToDbParameters( parameterList ) );

            howManyItems = table.Rows.Count;

            DataColumn[] keys = new DataColumn[] { table.Columns["TaxClassRuleID"] };
            table.PrimaryKey = keys;
            return ConvertTaxClassRuleTableToList( table, startIndex, endIndex );
        }

        public IList<TableSchemaItem> GetTableSchemas()
        {
            DataTable table = DataAccess.ExecuteSelect(
                "SELECT " + AllTaxClassRuleField +
                "FROM TaxClassRule " +
                "WHERE 0 = 1; " );

            return RepositoryUtilities.ConvertTableToSchemaItemList( table );
        }

        #endregion
    }
}
