using System;
using System.Collections.Generic;
using System.Data;
using System.Text;
using System.Web.UI;
using Vevo.Base.Data.Caching;
using Vevo.Domain;
using Vevo.Domain.DataInterfaces;
using Vevo.Domain.Orders;
using Vevo.Shared.Utilities;
using Vevo.Base.Domain;

namespace Vevo.Data
{
    public class OrderItemRepository : IOrderItemRepository
    {
        #region Private

        private const string RepositoryName = "OrderItemRepository";

        private const string GetOneSignature = "GetOne";
        private const string GetByOrderIDSignature = "GetByOrderID";
        private const string GetSubtotalSignature = "GetSubtotal";
        private const string GetAllChildOrderRecurringSignature = "GetAllChildOrderRecurring";
        private const string GetTableSchemaSignature = "GetTableSchema";
        private const string ExportOrderItemSignature = "ExportOrderItem";

        private DataCache _dataCache = new DataCache( RepositoryName );
        private ICacheDependencyUtility _cacheDependency
            = new CacheDependencyUtility( new string[] { "OrderItem", "Orders", "OrderItemRecurring" } );

        private OrderItemRepositoryNoCache _repository = new OrderItemRepositoryNoCache();

        #endregion

        #region Constructors

        public OrderItemRepository()
        {
        }

        public OrderItemRepository( ICacheDependencyUtility cacheDependency )
        {
            _cacheDependency = cacheDependency;
        }

        #endregion

        #region Public Methods

        public OrderItem Save( OrderItem orderItem )
        {
            // Need to write to database first before clearing cache.
            // Otherwise, cache may remember incorrect values before saving.
            OrderItem newOrderItem = _repository.Save( orderItem );
            _dataCache.ClearRepositoryCache();
            return newOrderItem;
        }

        public OrderItem GetOne( string orderItemID )
        {
            OrderItem result = (OrderItem) _dataCache.GetValue( GetOneSignature, _cacheDependency, orderItemID );

            if (result == null)
            {
                result = _repository.GetOne( orderItemID );
                _dataCache.SetValue( GetOneSignature, result, orderItemID );
            }

            return result;
        }

        public void Delete( string orderItemID )
        {
            _repository.Delete( orderItemID );
            _dataCache.ClearRepositoryCache();
        }

        public void DeleteByOrderID( string orderID )
        {
            _repository.DeleteByOrderID( orderID );
            _dataCache.ClearRepositoryCache();
        }

        public IList<OrderItem> GetByOrderID( string orderID )
        {
            IList<OrderItem> list = (IList<OrderItem>) _dataCache.GetValue( GetByOrderIDSignature, _cacheDependency, orderID );

            if (list == null)
            {
                list = _repository.GetByOrderID( orderID );
                _dataCache.SetValue( GetByOrderIDSignature, list, orderID );
            }

            return list;

        }

        public decimal GetSubtotal( string orderID )
        {
            decimal result = ConvertUtilities.ToDecimal( _dataCache.GetValue( GetSubtotalSignature, _cacheDependency, orderID ) );

            if (result == 0)
            {
                result = _repository.GetSubtotal( orderID );
                _dataCache.SetValue( GetSubtotalSignature, result, orderID );
            }

            return result;
        }

        public void UpdateRecurringItem( OrderItemRecurring orderItemRecurring )
        {
            _repository.UpdateRecurringItem( orderItemRecurring );
            _dataCache.ClearRepositoryCache();
        }

        public DataTable GetAllChildOrderRecurring( int orderID )
        {
            DataTable table = (DataTable) _dataCache.GetValue( GetAllChildOrderRecurringSignature, _cacheDependency, orderID );
            if (table == null)
            {
                table = _repository.GetAllChildOrderRecurring( orderID );
                _dataCache.SetValue( GetAllChildOrderRecurringSignature, table, orderID );
            }
            return table;
        }

        public IList<TableSchemaItem> GetTableSchema()
        {
            IList<TableSchemaItem> list = (IList<TableSchemaItem>) _dataCache.GetValue(
                GetTableSchemaSignature, _cacheDependency
                );

            if (list == null)
            {
                list = _repository.GetTableSchema();
                _dataCache.SetValue(
                    GetTableSchemaSignature,
                    list );
            }

            return list;
        }

        public IList<OrderItem> ExportOrderItem(
            string sortBy,
            SearchFilter searchFilter )
        {
            IList<OrderItem> list = (IList<OrderItem>) _dataCache.GetValue(
                ExportOrderItemSignature, _cacheDependency,
                sortBy,
                searchFilter.ToString() );

            if (list == null)
            {
                list = _repository.ExportOrderItem( sortBy, searchFilter );
                _dataCache.SetValue(
                    ExportOrderItemSignature,
                    sortBy,
                    searchFilter.ToString() );
            }

            return list;
        }

        #endregion
    }
}
