﻿using System;
using System.Collections;
using System.Collections.Generic;
using System.Data;
using Vevo.Data.Implementation;
using Vevo.Domain;
using Vevo.Domain.Base;
using Vevo.Domain.DataInterfaces;
using Vevo.Domain.Products;
using Vevo.Shared.DataAccess;
using Vevo.Shared.Utilities;
using Vevo.Base.Data;
using Vevo.Base.Domain;

namespace Vevo.Data
{
    public class ProductKitGroupRepositoryNoCache : IProductKitGroupRepository
    {
        #region Private

        private ProductKitItemAccess _productKitItemAccess = new ProductKitItemAccess();

        private void DeleteLocales( string productKitGroupID )
        {
            DataAccess.ExecuteNonQuery(
                "DELETE FROM ProductKitGroupLocale " +
                "WHERE ProductKitGroupID = @ProductKitGroupID; ",
                DataAccess.CreateParameterString( productKitGroupID ) );
        }

        private void InsertLocales( ProductKitGroup productKitGroup )
        {
            foreach (ProductKitGroupLocale locale in productKitGroup.Locales)
            {
                DataAccess.ExecuteNonQuery(
                    "INSERT INTO ProductKitGroupLocale (ProductKitGroupID, CultureID, Name, Description ) " +
                    "VALUES (@ProductKitGroupID, @CultureID, @Name, @Description );",
                    DataAccess.CreateParameterString( productKitGroup.ProductKitGroupID ),
                    DataAccess.CreateParameterString( locale.CultureID ),
                    DataAccess.CreateParameterString( locale.Name ),
                    DataAccess.CreateParameterString( locale.Description ) );
            }
        }

        private ProductKitGroup Create( ProductKitGroup productKitGroup )
        {
            string productKitGroupID = DataAccess.ExecuteScalar(
                "INSERT INTO ProductKitGroup ( Type, IsRequired ) " +
                "VALUES ( @Type, @IsRequired );" +
                "SELECT @@Identity; ",
                DataAccess.CreateParameterString( productKitGroup.Type.ToString() ),
                DataAccess.CreateParameterBool( productKitGroup.IsRequired ) );

            productKitGroup.ProductKitGroupID = productKitGroupID;

            InsertLocales( productKitGroup );
            _productKitItemAccess.SaveAll( productKitGroup.ProductKitGroupID, productKitGroup.ProductKitItems );

            return productKitGroup;
        }

        private ProductKitGroup Update( ProductKitGroup productKitGroup )
        {
            int update = DataAccess.ExecuteNonQuery(
                "UPDATE ProductKitGroup " +
                "SET Type = @Type, IsRequired = @IsRequired " +
                "WHERE ProductKitGroupID = @ProductKitGroupID; ",
                DataAccess.CreateParameterString( productKitGroup.Type.ToString() ),
                DataAccess.CreateParameterBool( productKitGroup.IsRequired ),
                DataAccess.CreateParameterString( productKitGroup.ProductKitGroupID ) );

            DeleteLocales( productKitGroup.ProductKitGroupID );
            InsertLocales( productKitGroup );

            _productKitItemAccess.SaveAll( productKitGroup.ProductKitGroupID, productKitGroup.ProductKitItems );

            return productKitGroup;
        }

        private ProductKitGroup.ProductKitGroupType GetProductKitGroupType( string productKitGroupType )
        {
            if (String.IsNullOrEmpty( productKitGroupType ))
                return ProductKitGroup.ProductKitGroupType.Unknown;
            else
                return (ProductKitGroup.ProductKitGroupType) Enum.Parse( typeof( ProductKitGroup.ProductKitGroupType ), productKitGroupType );
        }

        private ProductKitGroup CreateOneFromRow( Culture culture, DataRow row )
        {
            ProductKitGroup productKitGroup = new ProductKitGroup( culture );
            productKitGroup.ProductKitGroupID = row["ProductKitGroupID"].ToString();
            productKitGroup.Name = row["Name"].ToString();
            productKitGroup.IsRequired = ConvertUtilities.ToBoolean( row["IsRequired"] );
            productKitGroup.Type = (ProductKitGroup.ProductKitGroupType) Enum.Parse( typeof( ProductKitGroup.ProductKitGroupType ), row["Type"].ToString() );
            productKitGroup.Description = row["Description"].ToString();

            return productKitGroup;
        }

        private ProductKitGroupLocale CreateOneLocaleFromRow( DataRow row )
        {
            ProductKitGroupLocale locale = new ProductKitGroupLocale();
            locale.CultureID = row["CultureID"].ToString();
            locale.Name = row["Name"].ToString();
            locale.Description = row["Description"].ToString();

            return locale;
        }

        private List<ILocale> ConvertLocaleTableToList( DataTable localeTable )
        {
            List<ILocale> list = new List<ILocale>();

            foreach (DataRow row in localeTable.Rows)
                list.Add( CreateOneLocaleFromRow( row ) );

            return list;
        }

        private string ConvertFieldName( string fieldName )
        {
            switch (fieldName.ToLower())
            {
                case "productkitgroupid":
                    return "ProductKitGroup.ProductKitGroupID";
                default:
                    return fieldName;
            }
        }

        private IList<ProductKitGroup> ConvertTableToList( Culture defaultCulture, DataTable table )
        {
            IList<ProductKitGroup> list = new List<ProductKitGroup>();

            foreach (DataRow row in table.Rows)
                list.Add( CreateOneFromRow( defaultCulture, row ) );

            return list;
        }

        private IList<ProductKitGroup> ConvertTableToList( Culture culture, DataTable table, int startIndex, int endIndex )
        {
            IList<ProductKitGroup> list = new List<ProductKitGroup>();

            for (int i = startIndex; i <= endIndex && i < table.Rows.Count; i++)
                list.Add( CreateOneFromRow( culture, table.Rows[i] ) );

            return list;
        }

        private string CreateSortByText( string sortBy )
        {
            if (sortBy == null || sortBy.Trim() == "")
                return "";
            else if (sortBy.Trim().ToLower().StartsWith( "productkitgroupid" ))
                return "ORDER BY ProductKitGroup." + sortBy.Trim() + " ";
            else
                return "ORDER BY " + sortBy + " ";
        }

        private void CopyProductKitGroupLocales( ProductKitGroup productKitGroup, IList<ILocale> locales )
        {
            foreach (ProductKitGroupLocale locale in locales)
            {
                productKitGroup.Locales.Add( locale );
            }
        }

        #endregion


        #region Public Methods

        public ProductKitGroup Save( ProductKitGroup productKitGroup )
        {
            ProductKitGroup result;

            using (DataTransactionScope transaction = new DataTransactionScope())
            {
                if (productKitGroup.ProductKitGroupID == "0")
                    result = Create( productKitGroup );
                else
                    result = Update( productKitGroup );

                transaction.Complete();
            }

            return result;
        }

        public void Delete( string productKitGroupID )
        {
            using (DataTransactionScope transaction = new DataTransactionScope())
            {
                DataAccess.ExecuteNonQuery(
                    "DELETE FROM ProductKitGroup WHERE ProductKitGroupID = @ProductKitGroupID;",
                    DataAccess.CreateParameterString( productKitGroupID ) );
                DeleteLocales( productKitGroupID );

                _productKitItemAccess.DeleteByProductKitGroupID( productKitGroupID );

                transaction.Complete();
            }
        }

        public void DeleteLocalesByCultureID( string cultureID )
        {
            DataAccess.ExecuteNonQuery(
                "DELETE FROM ProductKitGroupLocale WHERE CultureID = @CultureID;",
                DataAccess.CreateParameterString( cultureID )
                );
        }

        public IList<ILocale> GetLocales( string productKitGroupID )
        {
            DataTable localeTable = DataAccess.ExecuteSelect(
                "SELECT ProductKitGroupID, CultureID, Name, Description " +
                "FROM ProductKitGroupLocale " +
                "WHERE ProductKitGroupID = @ProductKitGroupID; ",
                DataAccess.CreateParameterString( productKitGroupID ) );

            return ConvertLocaleTableToList( localeTable );
        }

        public ProductKitGroup GetOne( Culture culture, string productKitGroupID )
        {
            DataTable table = DataAccess.ExecuteSelect(
                "SELECT ProductKitGroup.ProductKitGroupID, Type, Name, Description, IsRequired " +
                "FROM ProductKitGroup LEFT JOIN " +
                "    (SELECT * FROM ProductKitGroupLocale WHERE CultureID = @CultureID) AS L " +
                "    ON ProductKitGroup.ProductKitGroupID = L.ProductKitGroupID " +
                "WHERE ProductKitGroup.ProductKitGroupID = @ProductKitGroup;",
                DataAccess.CreateParameterString( culture.CultureID ),
                DataAccess.CreateParameterString( productKitGroupID ) );

            if (table.Rows.Count > 0)
            {
                ProductKitGroup productKitGroup = CreateOneFromRow( culture, table.Rows[0] );
                CopyProductKitGroupLocales( productKitGroup, GetLocales( productKitGroupID ) );
                return productKitGroup;
            }
            else
                return ProductKitGroup.Null;
        }

        public IList<ProductKitGroup> GetByProductID( Culture culture, string productID )
        {
            DataTable result = DataAccess.ExecuteSelect(
                "SELECT ProductKitGroup.ProductKitGroupID, Type, Name, Description, IsRequired " +
                "FROM (ProductKit INNER JOIN ProductKitGroup ON ProductKit.ProductKitGroupID = " +
                "ProductKitGroup.ProductKitGroupID) INNER JOIN " +
                "ProductKitGroupLocale ON ProductKitGroup.ProductKitGroupID = " +
                "ProductKitGroupLocale.ProductKitGroupID " +
                "WHERE ProductID = @ProductID AND ProductKitGroupLocale.CultureID = @CultureID;",
                DataAccess.CreateParameterString( productID ),
                DataAccess.CreateParameterString( culture.CultureID ) );
            return ConvertTableToList( culture, result );
        }

        public IList<ProductKitGroup> GetAll( Culture culture )
        {
            return GetAll( culture, String.Empty );
        }

        public IList<ProductKitGroup> GetAll( Culture culture, string sortBy )
        {
            DataTable table = DataAccess.ExecuteSelect(
                "SELECT ProductKitGroup.ProductKitGroupID, Type, Name, Description, IsRequired " +
                "FROM ProductKitGroup LEFT JOIN " +
                "    (SELECT * FROM ProductKitGroupLocale WHERE CultureID = @CultureID) AS L " +
                "    ON ProductKitGroup.ProductKitGroupID = L.ProductKitGroupID " +
                CreateSortByText( sortBy ) + "; ",
                DataAccess.CreateParameterString( culture.CultureID ) );
            return ConvertTableToList( culture, table, 0, table.Rows.Count );
        }

        public IList<ProductKitGroup> GetAllByProductID( Culture culture, string productID, string sortBy )
        {
            DataTable table = DataAccess.ExecuteSelect(
                "SELECT ProductKitGroup.ProductKitGroupID, Type, Name, Description, IsRequired " +
                "FROM ( SELECT pg.*, CultureID, Name, Description " +
                "	    FROM ProductKitGroup pg LEFT JOIN ( " +
                "           SELECT * FROM ProductKitGroupLocale WHERE CultureID = @CultureID ) AS pl ON pg.ProductKitGroupID = pl.ProductKitGroupID " +
                "	  ) AS ProductKitGroup " +
                "	LEFT JOIN ProductKit pk ON ProductKitGroup.ProductKitGroupID = pk.ProductKitGroupID " +
                "WHERE ProductID = @ProductID " +
                CreateSortByText( sortBy ) + "; ",
                DataAccess.CreateParameterString( culture.CultureID ),
                DataAccess.CreateParameterString( productID ) );
            return ConvertTableToList( culture, table, 0, table.Rows.Count );
        }

        public IList<ProductKitGroup> GetAllExceptBaseProduct( Culture culture, string productID )
        {
            DataTable table = DataAccess.ExecuteSelect(
                "SELECT ProductKitGroup.ProductKitGroupID, Type, IsRequired, Name, Description " +
                "FROM ProductKitGroup " +
                "   LEFT JOIN " +
                "   (SELECT * FROM ProductKitGroupLocale WHERE CultureID = @CultureID) AS L " +
                "   ON L.ProductKitGroupID = ProductKitGroup.ProductKitGroupID " +
                "WHERE ProductKitGroup.ProductKitGroupID NOT IN " +
                "   (SELECT  ProductKitGroupID " +
                "    FROM ProductKitItem WHERE ProductID in ( @ProductID )) " +
                "AND ProductKitGroup.ProductKitGroupID IN (SELECT DISTINCT ProductKitGroupID FROM ProductKitItem); ",
                DataAccess.CreateParameterString( culture.CultureID ),
                DataAccess.CreateParameterString( productID ) );
            return ConvertTableToList( culture, table, 0, table.Rows.Count );
        }

        public void UpdateProductKitSortOrder( string productKit, string[] sortedProductKitGroup )
        {
            int sortCount = 0;
            foreach (string item in sortedProductKitGroup)
            {
                sortCount++;
                DataAccess.ExecuteNonQuery(
                    "UPDATE ProductKit SET SortOrder = @SortOrder WHERE ProductID = @ProductID AND ProductKitGroupID = @ProductKitGroupID;",
                    DataAccess.CreateParameterString( sortCount.ToString() ),
                    DataAccess.CreateParameterString( productKit ),
                    DataAccess.CreateParameterString( item ) );
            }
        }

        public IList<TableSchemaItem> GetTableSchema()
        {
            DataTable table = DataAccess.ExecuteSelect(
                "SELECT ProductKitGroup.ProductKitGroupID, Type, Name, Description, IsRequired " +
                "FROM ProductKitGroup LEFT JOIN " +
                "    (SELECT * FROM ProductKitGroupLocale) AS L " +
                "    ON ProductKitGroup.ProductKitGroupID = L.ProductKitGroupID WHERE 1 = 0 " );

            return RepositoryUtilities.ConvertTableToSchemaItemList( table );
        }

        public IList<ProductKitGroup> SearchProductKitGroup(
            Culture culture,
            string sortBy,
            SearchFilter searchFilter,
            int startIndex,
            int endIndex,
            out int howManyItems )
        {
            ArrayList parameterList = new ArrayList();
            parameterList.Add( DataAccess.CreateParameterString( RepositoryUtilities.GetCultureID( culture ) ) );

            SearchFilterHelperNew searchFilterHelper = new SearchFilterHelperNew();
            string optionFieldName = ConvertFieldName( searchFilter.FieldName );
            string commandSearch = searchFilterHelper.CreateCommandWithWhere( searchFilter, optionFieldName, parameterList );

            DataTable full = DataAccess.ExecuteSelect(
                "SELECT ProductKitGroup.ProductKitGroupID, Type, Name, Description, IsRequired " +
                "FROM ProductKitGroup LEFT JOIN " +
                "    (SELECT * FROM ProductKitGroupLocale WHERE CultureID = @CultureID) AS L " +
                "    ON ProductKitGroup.ProductKitGroupID = L.ProductKitGroupID " +
                commandSearch +
                CreateSortByText( sortBy ) + "; ",
                DataAccess.ConvertArrayListToDbParameters( parameterList )
                );

            howManyItems = full.Rows.Count;

            DataColumn[] keys = new DataColumn[] { full.Columns["ProductKitGroup.ProductKitGroupID"] };
            full.PrimaryKey = keys;
            return ConvertTableToList( culture, full, startIndex, endIndex );
        }

        public ProductKitItem GetOneItem( string productKitGroupID, string productID )
        {
            return _productKitItemAccess.GetOne( productKitGroupID, productID );
        }

        public IList<ProductKitItem> GetAllProductKitItems()
        {
            return _productKitItemAccess.GetAll();
        }

        public IList<ProductKitItem> GetProductKitItems( string productKitGroupID, Culture culture )
        {
            return _productKitItemAccess.GetByProductKitGroupID( productKitGroupID, culture );
        }

        public IList<ProductKitItem> GetProductKitItems( string productKitGroupID, string sortBy, Culture culture )
        {
            return _productKitItemAccess.GetByProductKitGroupID( productKitGroupID, sortBy, culture );
        }

        public void DeleteProductKitItemByGroupID( string productKitGroupID )
        {
            _productKitItemAccess.DeleteByProductKitGroupID( productKitGroupID );
        }
        public ProductKitItem GetProductKitItem( string productID )
        {
            return _productKitItemAccess.GetByProductID( productID );
        }

        public void DeleteProductKitItem( string productID, string productKitGroupID )
        {
            _productKitItemAccess.DeleteProductKitItem( productID, productKitGroupID );
        }

        public void DeleteProductKitItemByProductID( string productID )
        {
            _productKitItemAccess.DeleteByProductID( productID );
        }

        public void UpdateProductKitItemSortOrder( string productKitGroup, string[] sortedProductKitItems )
        {
            _productKitItemAccess.UpdateSortOrder( productKitGroup, sortedProductKitItems );
        }

        #endregion
    }
}
