using System;
using System.Collections.Generic;
using System.Text;
using Vevo.Domain;
using Vevo.Domain.DataInterfaces;
using Vevo.Base.Data.Caching;
using System.Web.UI;
using Vevo.Shared.Utilities;
using System.Data;
using Vevo.Domain.Stores;
using Vevo.Base.Domain;

namespace Vevo.Data
{
    public class StoreRepository : IStoreRepository
    {
        #region Private

        private const string RepositoryName = "StoreRepository";
        private const string GetOneSignature = "GetOne";
        private const string SearchStoreSignature = "SearchStore";
        private const string GetTableSchemaSignature = "GetTableSchema";
        private const string GetStoreIDByUrlNameSignature = "GetStoreIDByUrlName";
        private const string GetStoreIDByStoreNameSignature = "GetStoreIDByStoreName";
        private const string GetAllSignature = "GetAll";
        private const string TableName = "Store";
        private DataCache _dataCache = new DataCache( RepositoryName );
        private ICacheDependencyUtility _cacheDependency = new CacheDependencyUtility( TableName );
        private StoreRepositoryNoCache _repository = new StoreRepositoryNoCache();

        #endregion

        #region Constructors

        public StoreRepository()
        {
        }

        public StoreRepository( ICacheDependencyUtility cacheDependency )
        {
            _cacheDependency = cacheDependency;
        }

        #endregion

        #region IStoreRepository Members

        public Store Save( Store store )
        {
            // Need to write to database first before clearing cache.
            // Otherwise, cache may remember incorrect values before saving.
            Store newStore = _repository.Save( store );
            _dataCache.ClearRepositoryCache();
            return newStore;
        }

        public void Delete( string storeID )
        {
            _repository.Delete( storeID );
            _dataCache.ClearRepositoryCache();
        }

        public Store GetOne( string storeID )
        {
            Store result = (Store) _dataCache.GetValue( GetOneSignature, _cacheDependency, storeID );

            if (result == null)
            {
                result = _repository.GetOne( storeID );
                _dataCache.SetValue( GetOneSignature, result, storeID );
            }

            return result;
        }

        public IList<TableSchemaItem> GetTableSchema()
        {
            IList<TableSchemaItem> list = (IList<TableSchemaItem>) _dataCache.GetValue( GetTableSchemaSignature, _cacheDependency );

            if (list == null)
            {
                list = _repository.GetTableSchema();
                _dataCache.SetValue( GetTableSchemaSignature, list );
            }

            return list;
        }

        public IList<Store> SearchStore(
            string sortBy,
            SearchFilter searchFilter,
            int startIndex,
            int endIndex,
            out int howManyItems )
        {
            howManyItems = 0;
            Pair result = (Pair) _dataCache.GetValue(
                SearchStoreSignature,
                _cacheDependency,
                sortBy,
                searchFilter.ToString(),
                startIndex,
                endIndex
                );

            if (result == null)
            {
                result = new Pair();
                result.First
                    = _repository.SearchStore( sortBy, searchFilter, startIndex, endIndex, out howManyItems );
                result.Second = howManyItems;
                _dataCache.SetValue(
                    SearchStoreSignature,
                    result,
                    sortBy,
                    searchFilter.ToString(),
                    startIndex,
                    endIndex );
            }

            howManyItems = ConvertUtilities.ToInt32( result.Second );
            return (IList<Store>) result.First;
        }

        public string GetStoreIDByUrlName( string urlName )
        {
            string result = (String) _dataCache.GetValue(
                GetStoreIDByUrlNameSignature,
                _cacheDependency,
                urlName
                );
            if (String.IsNullOrEmpty( result ))
            {
                result = _repository.GetStoreIDByUrlName( urlName );
                _dataCache.SetValue(
                    GetStoreIDByUrlNameSignature,
                    result,
                    urlName
                    );
            }

            return result;

        }

        public string GetStoreIDByStoreName( string storeName )
        {
            string result = (String) _dataCache.GetValue(
                GetStoreIDByStoreNameSignature,
                _cacheDependency,
                storeName
                );
            if (String.IsNullOrEmpty( result ))
            {
                result = _repository.GetStoreIDByStoreName( storeName );
                _dataCache.SetValue(
                    GetStoreIDByStoreNameSignature,
                    result,
                    storeName
                    );
            }

            return result;

        }

        public IList<Store> GetAll( string sortBy )
        {
            IList<Store> list = (IList<Store>) _dataCache.GetValue( GetAllSignature, _cacheDependency, sortBy );

            if (list == null)
            {
                list = _repository.GetAll( sortBy );

                _dataCache.SetValue( GetAllSignature, list, sortBy );
            }
            return list;
        }
        #endregion
    }
}
