using System;
using System.Collections.Generic;
using System.Data;
using System.Text;

using Vevo.Data.Implementation;
using Vevo.Domain;
using Vevo.Domain.DataInterfaces;
using Vevo.Domain.Orders;
using Vevo.Shared.DataAccess;
using Vevo.Shared.Utilities;

namespace Vevo.Data
{
    public class WishListRepositoryNoCache : IWishListRepository
    {
        #region Private

        private const string AllWishListFields = " WishListID, CustomerID, CartID ";

        private WishList Create( WishList wishList )
        {
            wishList.WishListID = DataAccess.ExecuteScalar(
                "INSERT INTO WishList( CustomerID, CartID ) " +
                "VALUES ( @CustomerID, @CartID );SELECT @@Identity",
                DataAccess.CreateParameterString( wishList.CustomerID ),
                DataAccess.CreateParameterString( wishList.CartID ) );

            return wishList;
        }

        private WishList Update( WishList wishList )
        {
            DataAccess.ExecuteNonQuery(
                "UPDATE WishList " +
                "SET CustomerID = @CustomerID, " +
                "    CartID = @CartID " +
                "WHERE WishListID = @WishListID;",
                DataAccess.CreateParameterString( wishList.CustomerID ),
                DataAccess.CreateParameterString( wishList.CartID ),
                DataAccess.CreateParameterString( wishList.WishListID ) );

            return wishList;
        }

        private WishList CreateOneFromRow( DataRow row )
        {
            WishList wishList = new WishList();
            wishList.WishListID = row["WishListID"].ToString();
            wishList.CustomerID = row["CustomerID"].ToString();
            wishList.CartID = row["CartID"].ToString();

            return wishList;
        }

        private IList<WishList> ConvertTableToList( DataTable table )
        {
            return ConvertTableToList( table, 0, table.Rows.Count );
        }

        private IList<WishList> ConvertTableToList( DataTable table, int startIndex, int endIndex )
        {
            IList<WishList> list = new List<WishList>();

            for (int i = startIndex; i <= endIndex && i < table.Rows.Count; i++)
                list.Add( CreateOneFromRow( table.Rows[i] ) );

            return list;
        }

        #endregion


        #region Public Methods

        public WishList Save( WishList wishList )
        {
            WishList result;

            using (DataTransactionScope transaction = new DataTransactionScope())
            {
                if (ConvertUtilities.ToInt32( wishList.WishListID ) == 0)
                    result = Create( wishList );
                else
                    result = Update( wishList );

                transaction.Complete();
            }

            return result;
        }

        public WishList GetOne( string wishListID )
        {
            DataTable table = DataAccess.ExecuteSelect(
                "SELECT " + AllWishListFields +
                "FROM WishList " +
                "WHERE WishListID = @WishListID;",
                DataAccess.CreateParameterString( wishListID ) );

            if (table.Rows.Count > 0)
                return CreateOneFromRow( table.Rows[0] );
            else
                return WishList.Null;
        }

        public string GetWishListIDFromCustomerID( string customerID )
        {
            return DataAccess.ExecuteScalar(
                "SELECT WishListID FROM WishList " +
                "WHERE CustomerID = @CustomerID",
                DataAccess.CreateParameterString( customerID ) );
        }

        public bool IsExistCustomer( string customerID )
        {
            DataTable table = DataAccess.ExecuteSelect(
                "SELECT WishListID " +
                "FROM WishList " +
                "WHERE CustomerID = @CustomerID",
                DataAccess.CreateParameterString( customerID ) );

            if (table.Rows.Count > 0)
                return true;
            else
                return false;
        }

        public void DeleteAllByCustomerID( string customerID )
        {
            DataAccess.ExecuteNonQuery(
                "DELETE FROM WishList " +
                "WHERE CustomerID = @CustomerID",
                DataAccess.CreateParameterString( customerID ) );
        }

        public void DeleteAll()
        {
            DataAccess.ExecuteSelect( "DELETE FROM WishList;" );
        }

        #endregion
    }
}
