using System;
using System.Data;
using System.Collections;
using System.Collections.Generic;
using System.Configuration;
using System.IO;
using System.Web;
using System.Web.Security;
using System.Xml;
using Vevo.Domain;
using Vevo.Domain.Configurations;
using Vevo.Domain.International;
using Vevo.Domain.Shipping;
using Vevo.Domain.Users;
using Vevo.Shared.Utilities;
using Vevo.Shared.SystemServices;
using Vevo.WebAppLib;
using Vevo.Domain.Discounts;

namespace Vevo.Domain.Shipping.Usps
{
    /// <summary>
    /// Summary description for UspsShippingGateway
    /// </summary>
    public class UspsShippingGateway : IShippingGateway
    {
        #region Private

        private const string UspsPrefix = "USPS ";
        private const string ServiceListCacheName = "UspsShippingGateway_ServiceList";

        private ShippingOption _shippingOption;


        private string UserID
        {
            get { return DataAccessContext.Configurations.GetValue( "RTShippingUspsUserID" ); }
        }

        private bool UseMinWeightOrder
        {
            get { return DataAccessContext.Configurations.GetBoolValue( "RTShippingUspsIsMinWeight" ); }
        }

        private double MinWeightOrder
        {
            get { return DataAccessContext.Configurations.GetDoubleValue( "RTShippingUspsMinWeightOrder" ); }
        }

        private decimal MarkupPrice
        {
            get { return DataAccessContext.Configurations.GetDecimalValue( "RTShippingUspsMarkUpPrice" ); }
        }

        private bool IsFreeShipping
        {
            get { return DataAccessContext.Configurations.GetBoolValue( "RTShippingUspsIsFreeShipping" ); }
        }

        private decimal FreeShippingCost
        {
            get { return DataAccessContext.Configurations.GetDecimalValue( "RTShippingUspsFreeShippingCost" ); }
        }

        private string MerchantZip
        {
            get { return DataAccessContext.Configurations.GetValue( "RTShippingUspsMerchantZip" ); }
        }

        private string MerchantCountryCode
        {
            get { return "US"; }
        }

        private string UrlPost
        {
            get { return DataAccessContext.Configurations.GetValue( "RTShippingUspsUrl" ); }
        }

        private string MailType
        {
            get { return DataAccessContext.Configurations.GetValue( "RTShippingUspsMailType" ); }
        }

        private string[] ServiceEnabled()
        {
            string[] list = DataAccessContext.Configurations.GetValueList( "RTShippingUspsServiceEnabledList" );
            string[] result = new string[list.Length];

            for (int i = 0; i < list.Length; i++)
            {
                result[i] = GetNameByCode( list[i] );
            }
            return result;
        }

        private string[] ServiceFreeShipping()
        {
            string[] list = DataAccessContext.Configurations.GetValueList( "RTShippingUspsServiceFreeShipping" );
            string[] result = new string[list.Length];

            for (int i = 0; i < list.Length; i++)
            {
                result[i] = GetNameByCode( list[i] );
            }
            return result;
        }

        private string[] ServiceAllowedSetFreeShipping()
        {
            string[] list = DataAccessContext.Configurations.GetValueList( "RTShippingUspsServiceAllowedSetFree" );
            string[] result = new string[list.Length];

            for (int i = 0; i < list.Length; i++)
            {
                result[i] = GetNameByCode( list[i] );
            }
            return result;
        }

        private string[] ServiceAllowedUseCouponFreeShipping()
        {
            string[] list = DataAccessContext.Configurations.GetValueList( "RTShippingUspsServiceAllowedUseCouponFree" );
            string[] result = new string[list.Length];

            for (int i = 0; i < list.Length; i++)
            {
                result[i] = GetNameByCode( list[i] );
            }
            return result;
        }

        private int GetPounds( double weight )
        {
            return Convert.ToInt32( Math.Truncate( weight ) );
        }

        private double GetOunces( double weight )
        {
            int pounds = GetPounds( weight );
            double ounces = weight - pounds;
            return Math.Round( ounces * 16, 2 );
        }

        private string CreateTagDemesticPrefix()
        {
            return String.Format( "API=RateV3&XML=<RateV3Request USERID=\"{0}\">", UserID );
        }

        private string CreatePackageDomestic( string packageID, string destinationZip, double weight )
        {
            return String.Format( "<Package ID=\"{0}\"><Service>ALL</Service>" +
                "<ZipOrigination>{1}</ZipOrigination>" +
                "<ZipDestination>{2}</ZipDestination>" +
                "<Pounds>{3}</Pounds>" +
                "<Ounces>{4}</Ounces>" +
                "<Size>Regular</Size>" +
                "<Machinable>true</Machinable></Package>", packageID, MerchantZip, destinationZip, GetPounds( weight ), GetOunces( weight ) );
        }

        private string CreateTagDemesticPostfix()
        {
            return String.Format( "</RateV3Request>" );
        }

        private string CreateTagInternationalPrefix()
        {
            return String.Format( "API=IntlRate&XML=<IntlRateRequest USERID=\"{0}\">", UserID );
        }

        private string CreatePackageInternational( string packageID, double weight, string countryName )
        {
            return String.Format( "<Package ID=\"{0}\">" +
                "<Pounds>{1}</Pounds>" +
                "<Ounces>{2}</Ounces>" +
                "<MailType>{3}</MailType>" +
                "<Country>{4}</Country>" +
                "</Package>", packageID, GetPounds( weight ), GetOunces( weight ), MailType, countryName );
        }

        private string CreateTagInternationalPostfix()
        {
            return String.Format( "</IntlRateRequest>" );
        }

        private bool IsReturnError( XmlDocument xml )
        {
            XmlNodeList errorList = xml.GetElementsByTagName( "Error" );
            return (errorList.Count > 0);
        }

        private string GetErrorDescription( XmlDocument xml )
        {
            XmlNodeList xmlDescription = xml.GetElementsByTagName( "Description" );
            if (xmlDescription.Count > 0)
                return xmlDescription[0].InnerText;
            else
                return String.Empty;
        }

        private string GetRestrictions( XmlDocument xml )
        {
            XmlNodeList list = xml.GetElementsByTagName( "Restrictions" );

            if (list.Count > 0)
                return list[0].InnerText;
            else
                return String.Empty;
        }

        private bool IsServiceEnabled( string name )
        {
            bool result = false;
            string[] services = ServiceEnabled();
            foreach (string service in services)
            {
                name = name.Replace( "1-Day", "" );
                name = name.Replace( "2-Day", "" );
                name = name.Replace( "3-Day", "" );
                name = name.Replace( "Military", "" );
                name = name.Replace( "DPO", "" );

                if (name.Contains( "**" ))
                {
                    string[] namesplit = name.Split( '*' );
                    name = namesplit[0];
                }

                if (name == service)
                {
                    result = true;
                    break;
                }
            }
            return result;
        }

        private bool IsServiceFreeShipping( string name )
        {
            bool result = false;
            string[] services = ServiceFreeShipping();
            foreach (string service in services)
            {
                if (name == (UspsPrefix + service))
                {
                    result = true;
                    break;
                }
            }

            return result;
        }

        private bool IsServiceAllowedSetFreeShipping( string name, bool isContainFreeShippingItem )
        {
            bool result = false;
            if (isContainFreeShippingItem)
            {
                string[] services = ServiceAllowedSetFreeShipping();
                foreach (string service in services)
                {
                    if (name == (UspsPrefix + service))
                    {
                        result = true;
                        break;
                    }
                }
            }
            return result;
        }

        private bool IsAllowedUseCouponFreeShippingCost( string serviceCode, Coupon coupon )
        {
            bool result = false;

            if (coupon.DiscountType == Coupon.DiscountTypeEnum.FreeShipping)
            {
                string[] serviceList = ServiceAllowedUseCouponFreeShipping();

                foreach (string service in serviceList)
                {
                    if (serviceCode == (UspsPrefix + service))
                    {
                        result = true;
                        break;
                    }
                }
            }

            return result;
        }

        private ShippingChoice[] ConvertXmlDomesticToShippingOption(
            XmlDocument xml,
            out string errorMessage )
        {
            errorMessage = String.Empty;

            if (IsReturnError( xml ))
            {
                errorMessage = GetErrorDescription( xml );
                return new ShippingChoice[0];
            }
            else
            {
                ArrayList arList = new ArrayList();
                XmlNodeList list = xml.GetElementsByTagName( "Postage" );

                for (int i = 0; i < list.Count; i++)
                {
                    if (IsServiceEnabled( list[i]["MailService"].InnerText ))
                    {
                        string name = UspsPrefix + list[i]["MailService"].InnerText;
                        decimal shippingCost = Convert.ToDecimal( list[i]["Rate"].InnerText ) + MarkupPrice;
                        decimal handlingFee = _shippingOption.GetHandlingFee(
                            DataAccessContext.Configurations.GetBoolValue( "HandlingFeeEnabled" ), shippingCost );

                        ShippingChoice service = new ShippingChoice(
                            name, shippingCost, handlingFee );

                        arList.Add( service );
                    }
                }

                ShippingChoice[] services = new ShippingChoice[arList.Count];
                arList.CopyTo( services );

                return services;
            }
        }

        private ShippingChoice[] ConvertXmlInternationalToShippingOption(
            XmlDocument xml,
            out string errorMessage,
            out string restriction )
        {
            errorMessage = String.Empty;
            restriction = String.Empty;

            if (IsReturnError( xml ))
            {
                errorMessage = GetErrorDescription( xml );
                return new ShippingChoice[0];
            }
            else
            {
                ArrayList arList = new ArrayList();
                XmlNodeList list = xml.GetElementsByTagName( "Service" );

                for (int i = 0; i < list.Count; i++)
                {
                    if (IsServiceEnabled( list[i]["SvcDescription"].InnerText ))
                    {
                        string name = UspsPrefix + list[i]["SvcDescription"].InnerText;
                        decimal shippingCost =
                            ConvertUtilities.ToDecimal( list[i]["Postage"].InnerText ) + MarkupPrice;
                        decimal handlingFee = _shippingOption.GetHandlingFee(
                            DataAccessContext.Configurations.GetBoolValue( "HandlingFeeEnabled" ), shippingCost );

                        ShippingChoice service = new ShippingChoice( name, shippingCost, handlingFee );

                        arList.Add( service );
                    }
                }

                restriction = GetRestrictions( xml );

                ShippingChoice[] services = new ShippingChoice[arList.Count];
                arList.CopyTo( services );
                return services;
            }
        }

        private ShippingChoice[] GetServicesDomestic(
            string destinationZip,
            double weight,
            out string errorMessage )
        {
            string xmlPost = CreateTagDemesticPrefix()
                + CreatePackageDomestic( "First", destinationZip, weight )
                + CreateTagDemesticPostfix();

            try
            {
                HttpService httpService = new HttpService();
                string response = httpService.PostData( UrlPost, xmlPost );

                XmlDocument xml = new XmlDocument();
                xml.LoadXml( response );

                return ConvertXmlDomesticToShippingOption( xml, out errorMessage );
            }
            catch (Exception ex)
            {
                SaveLogFile.SaveLog( ex );
                if (!DataAccessContext.Configurations.GetBoolValue( "ShowDetailAjaxErrorMessage" ))
                {
                    errorMessage = ex.Message;
                    return new ShippingChoice[0];
                }
                else
                    throw;
            }
        }

        private ShippingChoice[] GetServicesInternational(
            double weight,
            string countryName,
            out string errorMessage,
            out string restriction )
        {
            string xmlPost = CreateTagInternationalPrefix()
                + CreatePackageInternational( "first", weight, countryName )
                + CreateTagInternationalPostfix();

            try
            {
                HttpService httpService = new HttpService();
                string response = httpService.PostData( UrlPost, xmlPost );

                XmlDocument xml = new XmlDocument();
                xml.LoadXml( response );
                return ConvertXmlInternationalToShippingOption( xml, out errorMessage, out restriction );
            }
            catch (Exception ex)
            {
                SaveLogFile.SaveLog( ex );
                if (!DataAccessContext.Configurations.GetBoolValue( "ShowDetailAjaxErrorMessage" ))
                {
                    errorMessage = ex.Message;
                    restriction = String.Empty;
                    return new ShippingChoice[0];
                }
                else
                    throw;
            }
        }

        private double GetWeightInPounds( double weight )
        {
            double result;
            if (UseMinWeightOrder && weight < MinWeightOrder)
                result = MinWeightOrder;
            else
                result = weight;

            if (DataAccessContext.Configurations.GetValue( "WeightUnit" ) == "KG")
            {
                return ConvertUtilities.ToDouble( WeightUtilities.ConvertKgToPounds( result ) );
            }
            else
            {
                return result;
            }
        }

        private static string GetNameByCode( string code )
        {
            DataTable table = ReadServiceFile();
            DataRow[] rows = table.Select( "Code = '" + code + "'" );
            if (rows.Length > 0)
                return rows[0]["Name"].ToString();
            else
                return String.Empty;
        }

        #endregion


        #region Constructors

        public UspsShippingGateway( ShippingOption shippingOption )
        {
            _shippingOption = shippingOption;
        }

        #endregion


        #region Public Methods

        public static DataTable ReadServiceFile()
        {
            DataTable serviceList = (DataTable) HttpContext.Current.Cache[ServiceListCacheName];
            if (serviceList == null)
            {
                DataSet ds = new DataSet();
                string pathFile = HttpContext.Current.Server.MapPath( "~/DataFiles/Shipping/UspsService.xml" );
                if (File.Exists( pathFile ))
                    ds.ReadXml( pathFile );
                else
                    throw new Exception( "File Not Found : " + pathFile );

                serviceList = new DataTable();
                serviceList = ds.Tables[0];

                HttpContext.Current.Cache[ServiceListCacheName] = serviceList;
            }
            return serviceList;
        }

        public string GetCountryName( StandardCountryCollection standardCountries, string countryCode )
        {
            // For USPS, some countries require certain names to be successfully processed.
            switch (countryCode)
            {
                case "GB": return "Great Britain and Northern Ireland";
                case "GE": return "Georgia, Republic of";
                case "KR": return "Korea, Republic of (South Korea)";
                case "SK": return "Slovak Republic";
                case "TW": return "Taiwan";
            }

            return standardCountries.GetCountry( countryCode ).CommonName;
        }

        public bool IsDomestic( string countryCode )
        {
            return countryCode == "US" || countryCode == "GU" || countryCode == "PR";
        }

        #endregion


        #region IShippingGateway Members

        public IList<ShippingChoice> RequestShippingChoices(
            Vevo.Base.Domain.ShippingAddress shippingAddress,
            Orders.Cart shoppingCart,
            decimal subtotal,
            bool isContainFreeShippingItem,
            Coupon coupon,
            out string errorMessage,
            out string restriction )
        {
            restriction = String.Empty;

            double weightResult = GetWeightInPounds( shoppingCart.GetTotalWeight() );
            ShippingChoice[] services;
            if (IsDomestic( shippingAddress.Country ))
            {
                services = GetServicesDomestic(
                    shippingAddress.Zip, weightResult, out errorMessage );
            }
            else
            {
                StandardCountryCollection standardCountries =
                    StandardCountryCollection.Create( new FileManager() );

                services = GetServicesInternational(
                    weightResult,
                    GetCountryName( standardCountries, shippingAddress.Country ),
                    out errorMessage,
                    out restriction );
            }

            if (IsFreeShipping && subtotal > FreeShippingCost)
            {
                for (int i = 0; i < services.Length; i++)
                {
                    if (IsServiceFreeShipping( services[i].Name ))
                    {
                        services[i].ShippingCost = 0;
                        services[i].HandlingFee = 0;
                    }
                }
            }

            if (ServiceAllowedSetFreeShipping().Length > 0)
            {
                for (int i = 0; i < services.Length; i++)
                {
                    if (IsServiceAllowedSetFreeShipping( services[i].Name, isContainFreeShippingItem ))
                    {
                        services[i].ShippingCost = 0;
                        services[i].HandlingFee = 0;
                    }
                }
            }

            if (ServiceAllowedUseCouponFreeShipping().Length > 0)
            {
                for (int i = 0; i < services.Length; i++)
                {
                    if (IsAllowedUseCouponFreeShippingCost( services[i].Name, coupon ))
                    {
                        services[i].ShippingCost = 0;
                        services[i].HandlingFee = 0;
                    }
                }
            }
            return services;
        }

        #endregion
    }
}