using System;
using System.Collections.Generic;
using System.Text;
using Vevo;
using Vevo.Domain.Exceptions;
using Vevo.Domain.Stores;
using Vevo.Base.Domain;

namespace Vevo.Domain.Configurations
{
    public class Configuration
    {
        #region Public Constances

        public enum ConfigurationType
        {
            DropDown,
            TextBox,
            RadioButton,
            Upload,
            UserControl,
            Unknow
        }
        #endregion

        #region Private

        private string _configID = "0";
        private string _name = String.Empty;
        private bool _searchable = false;
        private ConfigurationType _configType = ConfigurationType.Unknow;
        private string _selectionValues = String.Empty;
        private string _selectionNames = String.Empty;
        private string _selectionImages = String.Empty;
        private string _parentConfigName = String.Empty;
        private string _displayUserControl = String.Empty;
        private string _enablerConfigName = String.Empty;
        private string _fieldValidation = String.Empty;

        private IEntityList<ConfigurationValue> _values = new EntityList<ConfigurationValue>();
        private IEntityList<ConfigurationDescription> _descriptions = new EntityList<ConfigurationDescription>();


        private void AssertSingleCulture()
        {
            if (CanUseSingleCulture())
                return;

            throw new ConfigurationException(
                "The configuration '" + Name + "' supports multi-culture and requires culture parameter." );
        }

        private void AssertMultiCulture()
        {
            if (CanUseMultiCulture())
                return;

            throw new ConfigurationException(
                "The configuration '" + Name + "' does not support multi-culture " +
                "and does not accept culture parameter. " );
        }

        private void SetValuePrivate( string cultureID, string value )
        {
            SetValuePrivate( cultureID, value, Store.Null.StoreID );
        }

        private void SetValuePrivate( string cultureID, string value, string storeID )
        {
            ConfigurationValue configValue = FindValueByCultureIDAndStoreID( cultureID, storeID );
            if (configValue == null)
            {
                configValue = new ConfigurationValue( cultureID, storeID );
                Values.Add( configValue );
            }
            
            configValue.ItemValue = value;
            configValue.StoreID = storeID;
        }

        #endregion


        #region Constructors

        public Configuration( string name )
        {
            _name = name;
        }

        #endregion

        #region Custom Properties
        public IList<Configuration> ChildConfigurations
        {
            get
            {
                return DataAccessContext.ConfigurationRepository.GetByParentConfigName( Name );
            }
        }
        #endregion

        #region Public Properties

        public string ConfigID { get { return _configID; } set { _configID = value; } }
        public string Name { get { return _name; } }
        public bool Searchable { get { return _searchable; } set { _searchable = value; } }
        public ConfigurationType ConfigType { get { return _configType; } set { _configType = value; } }
        public string SelectionValues { get { return _selectionValues; } set { _selectionValues = value; } }
        public string SelectionNames { get { return _selectionNames; } set { _selectionNames = value; } }
        public string SelectionImages { get { return _selectionImages; } set { _selectionImages = value; } }
        public string ParentConfigName { get { return _parentConfigName; } set { _parentConfigName = value; } }
        public string DisplayUserControl { get { return _displayUserControl; } set { _displayUserControl = value; } }
        public string EnablerConfigName { get { return _enablerConfigName; } set { _enablerConfigName = value; } }
        public string FieldValidation { get { return _fieldValidation; } set { _fieldValidation = value; } }

        #endregion


        #region Custom Properties

        public IEntityList<ConfigurationValue> Values { get { return _values; } }
        public IEntityList<ConfigurationDescription> Descriptions { get { return _descriptions; } }

        #endregion


        #region Public Methods

        public bool CanUseSingleCulture()
        {
            if (Values.Count == 0)
                return true;

            if (Values.Count == 1 && Values[0].CultureID == Culture.Null.CultureID)
                return true;

            if (Values[0].CultureID == Culture.Null.CultureID)
                return true;

            return false;
        }

        public bool CanUseMultiCulture()
        {
            if (Values.Count == 0)
                return true;

            if (Values.Count > 1)
                return true;

            if (Values[0].CultureID != Culture.Null.CultureID)
                return true;

            return false;
        }

        public void SetValue( string value )
        {
            AssertSingleCulture();

            SetValuePrivate( Culture.Null.CultureID, value, Store.Null.StoreID );
        }

        public void SetValue( string value , Store store )
        {
            AssertSingleCulture();

            SetValuePrivate( Culture.Null.CultureID, value, store.StoreID );
        }

        public void SetValue( string cultureID, string value )
        {
            AssertMultiCulture();

            SetValuePrivate( cultureID, value, Store.Null.StoreID );
        }

        public void SetValue( string cultureID, string value, string storeID )
        {
            AssertMultiCulture();
            SetValuePrivate( cultureID, value, storeID );
        }

        public ConfigurationValue FindValueByCultureID( string cultureID )
        {
            foreach (ConfigurationValue configurationValue in Values)
            {
                if (configurationValue.CultureID == cultureID)
                    return configurationValue;
            }

            return null;
        }

        public ConfigurationValue FindValueByCultureIDAndStoreID( string cultureID, string storeID )
        {
            foreach (ConfigurationValue configurationValue in Values)
            {
                if (configurationValue.CultureID == cultureID && configurationValue.StoreID == storeID)
                    return configurationValue;
            }

            return null;
        }

        #endregion
    }
}
