using System;
using Vevo.Domain.Configurations;
using Vevo.Domain.Orders;

namespace Vevo.Domain.Payments
{
    public class GiftCertificate
    {
        #region Public Enum

        public enum ExpirationStatus
        {
            NotExpired,
            Expired,
            NoValue,
            NotActive,
            UnknownType
        }

        #endregion


        #region Private

        private string _giftCertificateCode = String.Empty;
        private string _productID = "0";
        private string _orderItemID = "0";
        private decimal _giftValue = 0;
        private decimal _remainValue = 0;
        private string _urlParameter = String.Empty;
        private string _recipient = String.Empty;
        private string _personalNote = String.Empty;
        private bool _isExpirable = false;
        private DateTime _expireDate = DateTime.Today;
        private bool _needPhysical = false;
        private bool _isActive = true;
        private ExpirationStatus _expireStatus = ExpirationStatus.UnknownType;


        private decimal GetTotalWithoutGiftCertificate(
            ConfigurationCollection configurations,
            decimal subtotal,
            decimal discount,
            decimal pointDiscount,
            decimal shippingCost,
            decimal handlingFee,
            decimal tax )
        {
            decimal sum = subtotal - discount - pointDiscount;
            if (!configurations.GetBoolValue( "GiftRedeemProductOnly" ))
            {
                sum += tax + shippingCost + handlingFee;
            }

            if (sum < 0)
                sum = 0;

            return Currency.RoundAmount( sum );
        }

        #endregion


        #region Constructors

        public GiftCertificate()
        {
        }

        #endregion


        #region Public Properties

        public static GiftCertificate Null
        {
            get { return NullGiftCertificate.Instance; }
        }

        public virtual bool IsNull
        {
            get { return false; }
        }

        public string GiftCertificateCode { get { return _giftCertificateCode; } set { _giftCertificateCode = value; } }
        public string ProductID { get { return _productID; } set { _productID = value; } }
        public string OrderItemID { get { return _orderItemID; } set { _orderItemID = value; } }
        public decimal GiftValue { get { return _giftValue; } set { _giftValue = value; } }
        public decimal RemainValue { get { return _remainValue; } set { _remainValue = value; } }
        public string UrlParameter { get { return _urlParameter; } set { _urlParameter = value; } }
        public string Recipient { get { return _recipient; } set { _recipient = value; } }
        public string PersonalNote { get { return _personalNote; } set { _personalNote = value; } }
        public bool IsExpirable { get { return _isExpirable; } set { _isExpirable = value; } }
        public DateTime ExpireDate { get { return _expireDate; } set { _expireDate = value; } }
        public bool NeedPhysical { get { return _needPhysical; } set { _needPhysical = value; } }
        public bool IsActive { get { return _isActive; } set { _isActive = value; } }
        public ExpirationStatus ExpireStatus { get { return _expireStatus; } set { _expireStatus = value; } }

        #endregion


        #region Public Methods

        public virtual decimal GetApplicableAmount(
            ConfigurationCollection configurations,
            CartItemGroup cartItemGroup,
            decimal subtotal,
            decimal discount,
            decimal pointDiscount,
            decimal shippingCost,
            decimal handlingFee,
            decimal tax,
            decimal reservedGiftAmount )        // This is the amount that has been reserved for other payments
        // already. This amount will not be used for this payment.
        {
            if (cartItemGroup.IsRecurring)
                return 0;

            decimal total = GetTotalWithoutGiftCertificate(
                configurations, subtotal, discount, pointDiscount, shippingCost, handlingFee, tax );

            decimal payableAmount = RemainValue - reservedGiftAmount;

            if (total > payableAmount)
            {
                return payableAmount;
            }
            else
            {
                return total;
            }
        }

        public bool Verify( out string errorMessage )
        {
            errorMessage = String.Empty;

            if (ExpireStatus != ExpirationStatus.NotExpired)
            {
                switch (ExpireStatus)
                {
                    case ExpirationStatus.Expired:
                        errorMessage = "Gift Certificate has been expired";
                        break;
                    case ExpirationStatus.NoValue:
                        errorMessage = "Gift Certificate does not have value";
                        break;
                    case ExpirationStatus.NotActive:
                        errorMessage = "Gift Certificate is not active";
                        break;
                    default:
                        errorMessage = "Invalid Gift Certificate Code";
                        break;
                }
                return false;
            }
            return true;
        }

        #endregion


        #region IClonable Members

        // Copy the whole aggregate (including locale)
        public object Clone()
        {
            GiftCertificate newObject = (GiftCertificate) MemberwiseClone();
            return newObject;
        }

        public CartItemGiftDetails CreateCartItemGiftDetails()
        {
            CartItemGiftDetails details = new CartItemGiftDetails(
                Recipient, PersonalNote, NeedPhysical, GiftValue );
            return details;
        }

        #endregion

    }
}
