﻿using System;
using System.Collections;
using System.Collections.Generic;
using System.Data;
using System.Web;
using Vevo.Domain;
using Vevo.Domain.Configurations;
using Vevo.Domain.Stores;
using Vevo.Shared.DataAccess;

namespace Vevo.WebAppLib
{
    /// <summary>
    /// Summary description for SystemConfig
    /// </summary>
    public static class SystemConfig
    {
        public struct ConfigurationDetails
        {
            public string Name;
            public string ItemValue;
            public string MainGroup;
            public string SubGroup;
            public string Description;
        }


        #region Constructors

        static SystemConfig()
        {
            Load();
        }

        #endregion


        #region Private
        private const string CachePrefix = "ConfigurationCache_";
        private const string NeutralCultureID = "0";
        private static ConfigurationCollection _configurations = DataAccessContext.Configurations;

        private enum ValueType { Single, MultiCulture }

        private static string GenerateCacheName( string cultureID )
        {
            return CachePrefix + cultureID;
        }

        private static IList<Configuration> GetConfigTable( string cultureID )
        {
            string key = GenerateCacheName( cultureID );

            IList<Configuration> configList = (IList<Configuration>) HttpRuntime.Cache[key];
            if (configList == null)
            {
                configList = DataAccessContext.ConfigurationRepository.GetAll();
                HttpRuntime.Cache[key] = configList;
            }

            return configList;
        }

        private static int GetDescriptionIndex( string cultureID, Configuration config )
        {
            for (int i = 0; i < config.Descriptions.Count; i++)
            {
                if (config.Descriptions[i].CultureID == cultureID)
                    return i;
            }
            throw new Exception( "Unknown cultureID " + cultureID + " for ConfigurationDescription" );
        }

        private static void CreateConfigConditionally(
            ValueType valueType,
            string cultureID,
            string name,
            string itemValue,
            string mainGroup,
            string subGroup,
            string description,
            string storeID )
        {
            if (!ContainsKey( name ))
            {
                Configuration config = new Configuration( name );
                ConfigurationValue value;
                if (valueType == ValueType.Single)
                    value = new ConfigurationValue( "0", "0" );
                else
                    value = new ConfigurationValue( cultureID, storeID );

                value.ItemValue = itemValue;
                config.Values.Add( value );

                ConfigurationDescription configDescription
                    = new ConfigurationDescription( cultureID );
                configDescription.Description = description;
                configDescription.MainGroup = mainGroup;
                configDescription.SubGroup = subGroup;
                config.Descriptions.Add( configDescription );

                DataAccessContext.ConfigurationRepository.Save( config );
            }
            else
            {
                Configuration config = _configurations[name];
                int descriptionIndex = GetDescriptionIndex( cultureID, config );
                if (config.Descriptions[descriptionIndex].Description != description)
                {
                    config.Descriptions[descriptionIndex].Description = description;
                    DataAccessContext.ConfigurationRepository.Save( config );
                }
            }
            DataAccessContext.ClearConfigurationCache();
        }

        private static void CreateConfigConditionally(
            ValueType valueType,
            string cultureID,
            string name,
            string itemValue,
            string mainGroup,
            string subGroup,
            string description,
            string keyword,
            string displayName,
            bool searchable,
            Configuration.ConfigurationType configType,
            string selectionValues,
            string selectionNames,
            string selectionImages,
            string parentConfigName,
            string displayUserControl,
            string enablerConfigName,
            string fieldValidation,
            string storeID
            )
        {
            if (!_configurations.ContainsKey( name ))
            {
                Configuration config = new Configuration( name );
                ConfigurationValue value;
                if (valueType == ValueType.Single)
                    value = new ConfigurationValue( "0", "0" );
                else
                    value = new ConfigurationValue( cultureID, storeID );
                value.ItemValue = itemValue;
                config.Values.Add( value );

                ConfigurationDescription configDescription
                    = new ConfigurationDescription( cultureID );
                configDescription.Description = description;
                configDescription.Keyword = keyword;
                configDescription.DisplayName = displayName;
                configDescription.MainGroup = mainGroup;
                configDescription.SubGroup = subGroup;
                config.Descriptions.Add( configDescription );

                config.Searchable = searchable;
                config.ConfigType = configType;
                config.SelectionValues = selectionValues;
                config.SelectionNames = selectionNames;
                config.SelectionImages = selectionImages;
                config.ParentConfigName = parentConfigName;
                config.DisplayUserControl = displayUserControl;
                config.EnablerConfigName = enablerConfigName;
                config.FieldValidation = fieldValidation;
                DataAccessContext.ConfigurationRepository.Save( config );
            }
            else
            {
                Configuration config = _configurations[name];
                int descriptionIndex = GetDescriptionIndex( cultureID, config );
                if (config.ConfigType != configType
                    || config.Searchable != searchable
                    || config.SelectionValues != selectionValues
                    || config.SelectionNames != selectionNames
                    || config.SelectionImages != selectionImages
                    || config.ParentConfigName != parentConfigName
                    || config.DisplayUserControl != displayUserControl
                    || config.EnablerConfigName != enablerConfigName
                    || config.FieldValidation != fieldValidation
                    || config.Descriptions[descriptionIndex].Keyword != keyword
                    || config.Descriptions[descriptionIndex].DisplayName != displayName
                    || config.Descriptions[descriptionIndex].Description != description
                    )
                {
                    config.ConfigType = configType;
                    config.Searchable = searchable;
                    config.SelectionValues = selectionValues;
                    config.SelectionNames = selectionNames;
                    config.SelectionImages = selectionImages;
                    config.ParentConfigName = parentConfigName;
                    config.DisplayUserControl = displayUserControl;
                    config.EnablerConfigName = enablerConfigName;
                    config.FieldValidation = fieldValidation;

                    config.Descriptions[descriptionIndex].Keyword = keyword;
                    config.Descriptions[descriptionIndex].DisplayName = displayName;
                    config.Descriptions[descriptionIndex].Description = description;
                    DataAccessContext.ConfigurationRepository.Save( config );
                }
            }
            DataAccessContext.ClearConfigurationCache();
        }

        private static void UpdateValueConditionally(
            string cultureID,
            string name,
            string itemValue,
            string storeID )
        {
            // If trying to update Thai culture using CultureIDs. while Thai culture does not
            // exist in the Culture table, then CultureIDs.Thai will return "0".
            // In that case, there is no need to add that item to the table.
            if (!String.IsNullOrEmpty( cultureID ) &&
                cultureID != "0")
            {
                Culture culture = DataAccessContext.CultureRepository.GetOne( cultureID );
                Store store = DataAccessContext.StoreRepository.GetOne( storeID );
                DataAccessContext.ConfigurationRepository.UpdateValue(
                    culture, DataAccessContext.Configurations[name], itemValue, store );
            }
        }

        private static void CreateMailServerConfiguration()
        {
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "SmtpServer", "127.0.0.1", "System", "Mail",
                "Enter your name or IP of your outgoing mail server", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "SmtpSslRequired",
                "False",
                "System",
                "Mail",
                "Select &ldquo;Yes&rdquo; to enable secure connection to your SMTP. If this option " +
                "is selected,<br />data encryption will be used for accessing SMTP. Please check with " +
                "your email<br />provider whether they support secure log on.", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "SmtpPort", "25", "System", "Mail",
                "Enter the port for this SMTP server. The default value is 21.", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "SmtpUserName",
                "",
                "System",
                "Mail",
                "Email User Name", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "SmtpPassword",
                "",
                "System",
                "Mail",
                "Email Password", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "SmtpAuthenRequired",
                "False",
                "System",
                "Mail",
                "Select this option to connect to your SMTP server with user name and password.", Store.Null.StoreID );

        }

        private static void CreateMerchantDetails()
        {
            CreateConfigConditionally(
                ValueType.MultiCulture,
                CultureIDs.English,
                "SiteName", "VevoCart", "Merchant", "Merchant",
                "This is your website name. This is not the value that will appear on the title bar <br />" +
                "of the first page of your website. For that you should modify the value of &ldquo;Title&rdquo;" +
                "<br />keyword of &ldquo;Default.aspx&rdquo; page in Langauges menu.", Store.Null.StoreID );

            UpdateValueConditionally(
                CultureIDs.Thai,
                "SiteName",
                "วีโวคาร์ต", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.MultiCulture,
                CultureIDs.English,
                "SiteDescription", "E-Commerce Solution", "Merchant", "Merchant",
                "This description will be put in HTML &lt;meta&gt; tag, which will be used <br />" +
                "by search engines such as Google to describe your page", Store.Null.StoreID );

            UpdateValueConditionally(
                CultureIDs.Thai,
                "SiteDescription",
                "ระบบอีคอมเมิร์ซ", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "CustomerServiceEmail", "service@localhost", "Merchant", "Merchant",
                "Email address for customer service account", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "EnableErrorLogEmail", "False", "Merchant", "Merchant",
                "Email notification when an error occurs", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "ErrorLogEmail", "error@localhost", "Merchant", "Merchant",
                "Email address for error notification", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "ContactUsEmail", "contactus@localhost", "Merchant", "Merchant",
                "Contact email address", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "AutoSenderEmail", "autosender@localhost", "Merchant", "Merchant",
                "Email address to be shown in 'From' field when an automated email has been generated", Store.Null.StoreID );

            CreateConfigConditionally( ValueType.Single,
                CultureIDs.English,
                "DomainRegistrationKey", "", "Merchant", "Merchant",
                "DomainRegistrationKey Store Value", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.MultiCulture,
                CultureIDs.English,
                "SiteKeyword", "", "Merchant", "Merchant",
                "This keyword will be put in HTML &lt;meta&gt; tag, which will be used <br />" +
                "by search engines such as Google to describe your page.<br/>The keyword can be separated by " +
                "commas (,)", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "EnableSiteGreetingText", "True", "Merchant", "Merchant",
                "Enable or disable greeting text at storefront.",
                "", "Enable Store Greeting Text", true, Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "",
                "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.MultiCulture,
                CultureIDs.English,
                "SiteGreetingText", "", "Merchant", "Merchant",
                "This keyword will be put in HTML &lt;meta&gt; tag, which will be used <br />" +
                "by search engines such as Google to describe your page.<br/>The keyword can be separated by " +
                "commas (,)", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "EnableAccountGreetingText", "True", "Merchant", "Merchant",
                "Enable or disable greeting text in MyAccount section.",
                "", "Enable MyAccount Greeting Text", true, Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "",
                "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.MultiCulture,
                CultureIDs.English,
                "AccountGreetingText", "", "Merchant", "Merchant",
                "This keyword will be put in HTML &lt;meta&gt; tag, which will be used <br />" +
                "by search engines such as Google to describe your page.<br/>The keyword can be separated by " +
                "commas (,)", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "EnableMap", "False", "Merchant", "Merchant",
                "Enable or disable map for store location",
                "", "Enable Map", true, Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "",
                "", "", "", Store.Null.StoreID);

            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "Latitude", "0", "Merchant", "Merchant",
                "Latitude of your store location", Store.Null.StoreID);

            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "Longitude", "0", "Merchant", "Merchant",
                "Longitude of your store location", Store.Null.StoreID);
        }

        private static void CreateDisplayConfiguration()
        {
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "LogoInvoiceImage",
                @"Images/logo.gif",
                "Display",
                "Display",
                "Path of image will display at invoice page.", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "CategoryItemsPerPage", "6", "Display", "Catalog",
                "This is the number of categories to show in category list page. <br />This is the list of " +
                "numbers separating by comma (ex. 1, 3, 5, 7).<br />The first value will be the default value. " +
                "<br />These values are selectable in the drop down list in the category list page.",
                "", "Number of displayed category", true,
                Configuration.ConfigurationType.TextBox, "", "", "", "", "", "", "Required|Expression", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "DepartmentItemsPerPage", "6", "Display", "Catalog",
                "This is the number of departments to show in department list page. <br />This is the list of " +
                "numbers separating by comma (ex. 1, 3, 5, 7).<br />The first value will be the default value. " +
                "<br />These values are selectable in the drop down list in the department list page.",
                "", "Number of displayed department", true,
                Configuration.ConfigurationType.TextBox, "", "", "", "", "", "", "Required|Expression", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "ProductItemsPerPage", "6", "Display", "Catalog",
                "This is the number of products to show in product list page.<br />This is the list of numbers " +
                "separating by comma (ex. 1, 3, 5, 7). <br />The first value will be the default value.<br />" +
                "These values are selectable in the drop down list in the product list page.",
                "", "Number of displayed products", true,
                Configuration.ConfigurationType.TextBox, "", "", "", "", "", "", "Required|Expression", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "TellAFriendEnabled", "True", "System", "Display",
                "This option enables or disables tell-a-friend for your website.<br/> If set to “No”, " +
                "this feature will be disabled. <br/>This is a global setting that affects all products.", "",
                "Enable Tell-A-Friend", true, Configuration.ConfigurationType.DropDown, "True|False",
                "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "NumberOfSubCategoryMenuColumn", "6", "Display", "Catalog",
                "Determine the number of category columns per row to show in category list at top category menu.",
                "", "Number of Displayed Sub Category Menu Column", true,
                Configuration.ConfigurationType.TextBox, "", "", "", "", "", "", "Required|Integer1,999", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "NumberOfSubCategoryMenuItem", "6", "Display", "Catalog",
                "Determine the number of category items per column to show in category list at top category menu.",
                "", "Number of Displayed Sub Category Menu Item", true,
                Configuration.ConfigurationType.TextBox, "", "", "", "", "", "", "Required|Integer1,999", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "NumberOfCategoryColumn", "2", "Display", "Catalog",
                "Determine the number of columns to show on catalog listing page.",
                "", "Number of Category Column", true,
                Configuration.ConfigurationType.TextBox, "", "", "", "", "", "", "Required|Integer1,999", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "NumberOfDepartmentColumn", "2", "Display", "Catalog",
                "Determine the number of columns to show on catalog listing page.",
                "", "Number of Department Column", true,
                Configuration.ConfigurationType.TextBox, "", "", "", "", "", "", "Required|Integer1,999", Store.Null.StoreID );

            CreateConfigConditionally(
               ValueType.Single, CultureIDs.English,
               "NumberOfProductColumn", "1", "Display", "Catalog",
               "Determine the number of columns to show on product listing page.",
               "", "Number of Product Column", true,
               Configuration.ConfigurationType.TextBox, "", "", "", "", "", "", "Required|Integer1,999", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "UseStockControl", "True", "Display", "Stock",
                "This option enables or disables inventory control for your website.<br/> If set to “No”, " +
                "there will be no out-of-stock. <br/>This is a global setting that affects all products.", "",
                "Use Inventory Control", true, Configuration.ConfigurationType.DropDown, "True|False",
                "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
              ValueType.Single, CultureIDs.English,
              "ShowQuantity", "True", "Display", "Stock",
              "If you set this option to “Yes”, the number of remaining product quantity in stocks will be<br/>" +
              "displayed in the storefront product details page.<br/>Note: The system will not display quantity " +
              "numbers for products that use options to keep track of stocks.",
              "", "Display Quantity On Hand", true,
            Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "OutOfStockValue", "2", "Display", "Stock",
                "Minimal number of items required in stock.<br/>If the items are not greater than this value," +
                "<br/>the store front will show the customers that this item is out of stock.",
                "", "Out of stock quantity", true, Configuration.ConfigurationType.TextBox,
                "", "", "", "", "", "", "Required|Integer", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "RandomProductShow", "6", "Display", "Stock",
                "Determine the number of random products to show on your home page.<br/>The Random Product " +
                "section is also called Featured Products.", "", "Number of Random Products", true,
                Configuration.ConfigurationType.TextBox, "", "", "", "", "", "", "Required|Integer1,999", Store.Null.StoreID );

            CreateConfigConditionally(
               ValueType.Single, CultureIDs.English,
               "ProductBestSellingShow", "2", "System", "Display",
               "Determine the number of best selling products displayed in the first page.",
               "", "Number of Best Selling", true,
               Configuration.ConfigurationType.TextBox, "", "", "", "", "", "", "Required|Integer1,999", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "DefaultImageUrl", "Images/Design/DefaultNoImage.gif", "Display", "Image",
                "Default image to show if product does not have image", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "IsCatalogMode", "False", "Display", "Display",
                "This option can be &ldquo;Shopping Cart&rdquo; for a normal online store<br /> or " +
                "&ldquo;Catalog&rdquo; for a catalog-only website.<br />Please see User Manual for more details.",
                "", "Website Mode", true, Configuration.ConfigurationType.DropDown, "True|False",
                "Catalog|Shopping Cart", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "WholesaleMode", "0", "Display", "Display",
                "This option can enable the wholesale mode, which allows users flagged<br />with " +
                "&ldquo;Wholesale&rdquo; to shop with special prices.<br />Please see VevoCart User Manual " +
                "for more details.", "",
                "Wholesale Mode", true, Configuration.ConfigurationType.UserControl, "", "", "", "",
                "Components/SiteConfig/Wholesale.ascx", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "WholesaleLevel", "0", "Display", "Display",
                "Set wholesale level for wholesale customer.", "", "Number of Wholesale Levels", false,
                Configuration.ConfigurationType.UserControl, "", "", "", "WholesaleMode",
                "Components/SiteConfig/Wholesale.ascx", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
               ValueType.Single, CultureIDs.English,
               "DiscountLevel1", "0", "Display", "Display",
               "Set Discount percentage of wholesale price for wholesale customer level 1.", "",
               "Discount Level 1", false, Configuration.ConfigurationType.UserControl, "", "", "",
               "WholesaleMode", "Components/SiteConfig/Wholesale.ascx", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
              ValueType.Single, CultureIDs.English,
              "DiscountLevel2", "0", "Display", "Display",
              "Set Discount percentage of wholesale price for wholesale customer level 2.", "",
              "Discount Level 2", false, Configuration.ConfigurationType.UserControl, "", "", "",
              "WholesaleMode", "Components/SiteConfig/Wholesale.ascx", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
              ValueType.Single, CultureIDs.English,
              "DiscountLevel3", "0", "Display", "Display",
              "Set Discount percentage of wholesale price for wholesale customer level 3.", "",
              "Discount Level 3", false, Configuration.ConfigurationType.UserControl, "", "", "",
              "WholesaleMode", "Components/SiteConfig/Wholesale.ascx", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "RetailPriceMode", "True", "Display", "Display",
                "If this option is disabled, the retail price will not be shown in the storefront<br/>" +
                "as well as the Product menu in Admin website.", "", "Show Retail Price", true,
                Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "ShowSkuMode", "False", "Display", "Display",
                "If this option is enabled, the product SKU will display in product details page.",
                "", "Show Product SKU", true,
                Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "MerchantRating", "True", "System", "Display",
                "Enable or disable merchant rating. If disabled, customers cannot see the merchant rating.",
                "", "Merchant Rating", true,
                Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "CustomerRating", "True", "System", "Display",
                "Enable or disable customer rating. If disabled, customers cannot edit or view the customer " +
                "rating.", "", "Customer Rating", true,
                Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "CustomerReview", "True", "System", "Display",
                "Enable or disable customer review. If disabled, customers cannot see the customer review.",
                "", "Customer Review", true,
                Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "ReviewRequireLogin", "True", "System", "Display",
                "If enabled, customers must login before giving the review.", "", "Review Require Login", true,
                Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "RatingRequireLogin", "True", "System", "Display",
                "If enabled, customers must login before giving the rating.", "", "Rating Require Login", true,
                Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "StarRatingAmount", "5", "System", "Display",
                "This is the global setting for maximum number of stars for rating.", "", "Number of Stars", true,
                Configuration.ConfigurationType.TextBox, "", "", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "ReviewDisplayNameBy", "UserName", "System", "Display",
                "The option to display customer name by: Username, Full Name, First Name, or Last Name.",
                "", "Display Customer By", true,
                Configuration.ConfigurationType.DropDown, "UserName|FullName|FirstName|LastName",
                "User Name|Full Name|First Name|Last Name", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "IsDisplayOptionInProductList", "False", "Display", "Display",
                "This configuration determines whether Product Options should be shown<br/>in product list page " +
                "when customers browse the store.", "", "Display Option in product list page", true, Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "LogoImage",
                "",
                "Display",
                "Display",
                "Merchants can upload the website logo here.", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "ThumbnailImageWidth",
                "70",
                "Display",
                "Display",
                "Width of thumbnail Image.", Store.Null.StoreID );

            CreateConfigConditionally(
               ValueType.Single,
               CultureIDs.English,
               "ThumbnailImageHeight",
               "70",
               "Display",
               "Display",
               "Height of thumbnail Image.", Store.Null.StoreID );

            CreateConfigConditionally(
               ValueType.Single, CultureIDs.English,
               "SiteMapEnabled", "True", "Display", "Display",
               "If this option is disabled, the site map will not show in the store front.",
               "", "Display Site Map", true,
               Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
              ValueType.Single, CultureIDs.English,
              "SiteMapDisplayType", "showall", "Display", "Display",
              "Set sitemap display mode for lager product catalog.", "", "Site Map Display Type", false,
              Configuration.ConfigurationType.DropDown, "showall|showcategoriesonly",
              "Show All|Show Categories Only", "", "SiteMapEnabled", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "CategoryMenuType", "default", "Display", "Display",
                "Determine type of sidebar category menu consists of: Default style, Cascade style, " +
                "and Tree style.", "", "Sidebar Category Menu Type", true,
                Configuration.ConfigurationType.DropDown, "default|cascade|treeview",
                "Default|Cascade|Tree View", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "DepartmentMenuType", "default", "Display", "Display",
                "Determine type of sidebar department menu consists of: Default style, Cascade style, " +
                "and Tree style.", "", "Sidebar Department Menu Type", true,
                Configuration.ConfigurationType.DropDown, "default|cascade|treeview",
                "Default|Cascade|Tree View", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "CategoryShowProductList", "False", "Display", "Display",
                "Show product list in category list page.", "", "Show product in category list", true,
                Configuration.ConfigurationType.DropDown, "True|False",
                "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "DepartmentShowProductList", "False", "Display", "Display",
                "Show product list in department list page.", "", "Show product in department list", true,
                Configuration.ConfigurationType.DropDown, "True|False",
                "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "CategoryMenuLevel", "5", "Display", "Display",
                "Determine maximum number of level of subcategories that can be displayed in " +
                "Sidebar Category Menu.", "", "Sidebar Category Menu Level", true,
                Configuration.ConfigurationType.TextBox, "", "", "", "", "", "", "Required|Integer", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "DepartmentMenuLevel", "5", "Display", "Display",
                "Determine maximum number of level of subcategories that can be displayed in " +
                "Sidebar Department Menu.", "", "Sidebar Department Menu Level", true,
                Configuration.ConfigurationType.TextBox, "", "", "", "", "", "", "Required|Integer", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "QuantityDiscountSeparateOption", "False", "System", "Display",
                "If enabled, the quantity discount will be calculated based on product options.<br/>Please see " +
                "more information in the User Manual.", "",
                "Calculate quantity discount separately for product options", true,
                Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
               ValueType.Single, CultureIDs.English,
               "WishListEnabled", "True", "System", "Display",
               "Enable or disable Wish List. If it’s disable the wish list will not shown in storefront.",
               "", "Wishlist", true,
               Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
               ValueType.Single, CultureIDs.English,
               "CompareListEnabled", "False", "System", "Display",
               "Enable or disable Compare List. If it’s disable the compare list will not shown in storefront.",
               "", "Compare List", true,
               Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
               ValueType.Single, CultureIDs.English,
               "CompareProductShow", "3", "System", "Display",
               "Determine the number of compare products to show on your home page.", "", "Number of Compare Product", true,
               Configuration.ConfigurationType.TextBox, "", "", "", "", "", "", "Required|Integer1,999", Store.Null.StoreID );


            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "CouponEnabled", "True", "System", "System",
                "This option enables or disables coupon.<br/>If disabled, the coupon box will not be shown " +
                "in the storefront and check out page.", "", "Enable Coupon", true,
                Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "StoreTheme", "Default", "System", "Display",
                "This is website theme setting.", "", "Theme", true,
                Configuration.ConfigurationType.UserControl, "", "", "", "",
                "Components/SiteConfig/LayoutThemeSelect.ascx", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "MobileTheme", "MobileTheme", "System", "Display",
                "This is website mobile theme setting.", "", "Mobile Theme", true,
                Configuration.ConfigurationType.UserControl, "", "", "", "",
                "Components/SiteConfig/LayoutMobileThemeSelect.ascx", "", "", Store.Null.StoreID );

            CreateConfigConditionally( ValueType.Single, CultureIDs.English, "MobileView", "True", "Mobile", "MobileView",
                "Store allows merchant to enabled or disabled mobile view. If this option is enabled, the store will redirect to mobile when customer browse your website via mobile",
                "", "Enabled Mobile View", true, Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "DefaultCategoryListLayout", "CategoryListDefault.ascx", "System", "Display",
                "This is default layout of category list display.", "", "Category List Default layouts", true,
                Configuration.ConfigurationType.UserControl, "", "", "", "",
                "Components/SiteConfig/LayoutCategoryListSelect.ascx", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "DefaultDepartmentListLayout", "DepartmentListDefault.ascx", "System", "Display",
                "This is default layout of department list display.", "", "Department List Default layouts", true,
                Configuration.ConfigurationType.UserControl, "", "", "", "",
                "Components/SiteConfig/LayoutDepartmentListSelect.ascx", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "DefaultProductListLayout", "ProductListRowStyle.ascx", "System", "Display",
                "This is default layout of product list display.", "", "Product List Default layouts", true,
                Configuration.ConfigurationType.UserControl, "", "", "", "",
                "Components/SiteConfig/LayoutProductListSelect.ascx", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "DefaultProductDetailsLayout", "ProductDetailsDefault.ascx", "System", "Display",
                "This is default layout of product detail display.", "", "Product Details Default layouts", true,
                Configuration.ConfigurationType.UserControl, "", "", "", "",
                "Components/SiteConfig/LayoutProductDetailsSelect.ascx", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "IsPolicyAgreementEnabled", "False", "System", "Display",
                "This option enables or disables policy agreement.<br/>If enabled, Customer must agree the policy " +
                "before order.", "", "Enable Policy agreement", true,
                Configuration.ConfigurationType.UserControl, "", "", "", "",
                "Components/SiteConfig/PolicyAgreement.ascx", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "CanonicalizationLayout", "False", "System", "Display",
                "This option enables or disables Canonicalization.<br/>The canonicalization deals with web content " +
                "that has more than one possible URL.", "", "Enable Canonicalization", true,
                Configuration.ConfigurationType.UserControl, "", "", "", "",
                "Components/SiteConfig/Canonicalization.ascx", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "CanonicalizationStore", "", "System", "Display",
                "Tells search engine that product, category, and department pages<br />are refer to the canonical page of selected store.",
                "", "Preferred Store", false, Configuration.ConfigurationType.DropDown, "", "", "", "CanonicalizationLayout",
                "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "CustomerAutoApprove", "True", "System", "Display",
                "Customers will be approved automatically registered when the customer register successfully<br/>" +
                "If set to No, Customer account must be approved by merchant before they visit the website.",
                "", "Customer Auto Approve", true, Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "",
                "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "FBLikeButton", "False", "System", "Display", "This option enables or disables Facebook like button in product details page",
                "", "Facebook like button", true, Configuration.ConfigurationType.DropDown,
                "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "RecentlyViewedProductShow", "6", "System", "Display",
                "Determine the number of recently viewed products to show on your home page.", "", "Number of Recently Viewed Products", true,
                Configuration.ConfigurationType.TextBox, "", "", "", "", "", "", "Required|Integer1,999", Store.Null.StoreID );

            CreateConfigConditionally(
              ValueType.Single, CultureIDs.English,
              "RecentlyViewedProductDisplay", "True", "Display", "Layout",
              "Enable or disable recently view product box.<br/>If disabled, the recently view product box will not be shown " +
              "in the storefront.", "", "Recently Viewed Product", true,
              Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
              ValueType.Single, CultureIDs.English,
              "RestrictAccessToShop", "False", "Display", "Layout",
              "Enable or disable restrict access to shop.<br/>If enabled, Stores will force all users to login before " +
              "viewing content in the shop.", "", "Restrict Access To Shop", true,
              Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
              ValueType.Single, CultureIDs.English,
              "PriceRequireLogin", "False", "Display", "Layout",
              "Enable or disable price require login.<br/>If enabled, Users will not be able to see all product price in store " +
              "until the user login already.", "", "View Price Require Login", true,
              Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
               ValueType.Single, CultureIDs.English,
               "StoreDefaultCountry", "US", "System", "Display",
               "Set default country to use in store<br/>Country drop down in the storefront is set to automatically select the country",
               "", "Store Default Country Dropdown", true,
               Configuration.ConfigurationType.UserControl, "", "", "", "", "Components/CountryList.ascx", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
              ValueType.Single, CultureIDs.English,
              "SaleTaxExempt", "False", "Display", "Layout",
              "Store allows customers to enter tax exemption information on purchases in the store. <br/>" +
              "If this option is enabled, the store will display tax exempt for enter tax exempt ID and shipping state",
              "", "Sale Tax Exempt", true,
              Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "CheckoutMode", "Normal", "Display", "Layout",
                "Set checkout mode to be used in your store. <br/>" +
                "Normal mode will be separated to multiple steps. One page mode will be merged to one page.",
                "", "Checkout Mode", true,
                Configuration.ConfigurationType.DropDown, "Normal|One Page", "Normal|One Page", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
              ValueType.Single, CultureIDs.English,
              "EnableBundlePromo", "False", "Display", "Display",
              "If this option is enabled, the store will display bunble promotion box for show your promotion.<br/>" +
              "You can create bundle promotion in the marketing menu.",
              "", "Enable Bundle Promotion", true,
              Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
               ValueType.Single, CultureIDs.English,
               "ProductBestSellingShow", "2", "System", "Display",
               "Determine the number of best selling products displayed in the first page.",
               "", "Number of Best Selling", true,
               Configuration.ConfigurationType.TextBox, "", "", "", "", "", "", "Required|Integer1,999", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "BundlePromotionShow", "1", "System", "Display",
                "Determine the number of promotion to show on your home page.", "", "Number of Bundle Promotion", true,
                Configuration.ConfigurationType.TextBox, "", "", "", "", "", "", "Required|Integer1,999", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "BundlePromotionColumn", "1", "System", "Display",
                "Determine the number of columns to show on promotion listing page.", "", "Number of Bundle Promotion Column", true,
                Configuration.ConfigurationType.TextBox, "", "", "", "", "", "", "Required|Integer1,999", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "BundlePromotionDisplay", "6", "System", "Display",
                "This is the number of promotion to show in promotion list page.<br/>This is the list of numbers separating by comma (ex. 1, 3, 5, 7).<br/>" +
                "The first value will be the default value.<br/>These values are selectable in the drop down list in the promotion list page.", "",
                "Number of Displayed Bundle Promotion", true,
                Configuration.ConfigurationType.TextBox, "", "", "", "", "", "", "Required|Integer1,999", Store.Null.StoreID );

            CreateConfigConditionally(
              ValueType.Single, CultureIDs.English,
              "EnableRMA", "False", "System", "Display",
              "Return Merchandise Authorization (RMA)<br/>" +
              "If this option is enabled, the store will allows customers to send a RMA request to merchant",
              "", "Enable RMA", true,
              Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "SearchMode", "any", "System", "Display",
                "Set the default search mode for using in quick search.",
                "", "Default Search Mode", true,
                Configuration.ConfigurationType.DropDown, "All words|Any words|Exact phase", "All words|Any words|Exact phase", "", "", "", "", "", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "FacetedSearchEnabled", "True", "System", "Display",
                "Faceted Search<br/>" +
                "If this option is enabled, faceted search is display in store front",
                "", "Faceted Search", true,
                Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "PriceNavigationStep", "500", "System", "Display",
                "Set this value for price range increment in each step.",
                "", "Price Navigation Step", true, Configuration.ConfigurationType.TextBox,
                "", "", "", "FacetedSearchEnabled", "", "", "Required", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "MaximunInterval", "3", "System", "Display",
                "Setup maximum interval that display on faceted search.",
                "", "Maximum Interval", true, Configuration.ConfigurationType.TextBox,
                "", "", "", "FacetedSearchEnabled", "", "", "Required", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "EnableReviewPerCulture", "False", "System", "Display",
                "If this option is enabled, the store will display product review and allows customers to post the review in selected language only.",
                "", "Enable Customer Review Per Culture", true,
                Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally( ValueType.Single, CultureIDs.English, "EnableManufacturer", "True", "Manufacturer", "EnableManufacturer",
                "Store allows merchant to enabled or disabled Manufacturer. If this option is enabled, the store will display Manufacturer at Store front",
                "", "Enable Manufacturer", true, Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally( ValueType.Single, CultureIDs.English, "ManufacturerMenuType", "default", "Manufacturer", "ManufacturerMenuType",
                "Determine type of manufacturer menu consists of: Default style, Drop Down style.",
                "", "Sidebar Manufacturer Menu Type", true, Configuration.ConfigurationType.DropDown, "default|dropdown", "Default|Drop Down", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally( ValueType.Single, CultureIDs.English,
                "EnableAddToCartNotification", "False", "System", "Display",
                "If this option is enabled, the store will display the Add To Cart notification popup when customer click Add To Cart Button. If this option is disalbed, the store will redirect to shopping cart page when customer click Add To Cart Button.",
                "", "Enable Add To Cart Notification", true,
                Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally( ValueType.Single, CultureIDs.English,
                "EnableQuickView", "False", "System", "Display",
                "If this option is enabled, the store will display the QuickView Button.",
                "", "Enable QuickView", true,
                Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "ManufacturerItemsPerPage", "6", "Display", "Catalog",
                "This is the number of manufacturer to show in manufacturer list page. <br />This is the list of " +
                "numbers separating by comma (ex. 1, 3, 5, 7).<br />The first value will be the default value. " +
                "<br />These values are selectable in the drop down list in the manufacturer list page.",
                "", "Number of Displayed Manufacturer", true,
                Configuration.ConfigurationType.TextBox, "", "", "", "", "", "", "Required|Expression", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "EnableNewArrivalProduct", "True", "System", "Display",
                "If this option is enabled, the store will display new arrival product in default page.<br />" +
                "The new arrival products are sorted by create date of product attribute.",
                "", "Enable Display New Arrival Product", true,
                Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "ProductNewArrivalNumber", "3", "System", "Display",
                "Determine the number of new arrival products per page displayed in default page.",
                "", "Number of New Arrival Product Per Page", true,
                Configuration.ConfigurationType.TextBox, "", "", "", "", "", "", "Required|Integer", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "MaximumDisplayProductNewArrival", "15", "System", "Display",
                "Determine the maximum number of new arrival products displayed in default page.",
                "", "Maximum Number of New Arrival Product", true,
                Configuration.ConfigurationType.TextBox, "", "", "", "", "", "", "Required|Integer", Store.Null.StoreID );
        }

        private static void CreateSingleCustomConfiguration( ConfigurationCollection ConfigurationCollection )
        {
            if (ConfigurationCollection == null) return;
            for (int i = 0; i < ConfigurationCollection.Count; i++)
            {
                Configuration configuration = ConfigurationCollection.Values[i];
                CreateConfigConditionally( ValueType.Single, CultureIDs.English, configuration.Name, configuration.Values[0].ItemValue, configuration.Descriptions[0].MainGroup, configuration.Descriptions[0].SubGroup, configuration.Descriptions[0].Description, configuration.Descriptions[0].Keyword, configuration.Descriptions[0].DisplayName, configuration.Searchable, configuration.ConfigType, configuration.SelectionValues, configuration.SelectionNames, configuration.SelectionImages, configuration.ParentConfigName, configuration.DisplayUserControl, configuration.EnablerConfigName, configuration.FieldValidation, Store.Null.StoreID );
            }
        }

        private static void CreateLayoutConfiguration()
        {
            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "CategoryListModuleDisplay", "True", "Display", "Layout",
                "Enable or disable category list menu.<br/>If disabled, the category list menu will not be " +
                "shown in the storefront.", "", "Category List", true,
                Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "DepartmentListModuleDisplay", "False", "Display", "Layout",
                "Enable or disable department list menu.<br/>If disabled, the department list menu will not be " +
                "shown in the storefront.", "", "Department List", true,
                Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "DepartmentHeaderMenuDisplay", "False", "Display", "Layout",
                "Enable or disable department header menu.<br/>If disabled, the department header menu will not be " +
                "shown in the storefront.", "", "Display Department Header Menu", true,
                Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "ManufacturerHeaderMenuDisplay", "False", "Display", "Layout",
                "Enable or disable manufacturer header menu.<br/>If disabled, the manufacturer header menu will not be " +
                "shown in the storefront.", "", "Display Manufacturer Header Menu", true,
                Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "HeaderMenuStyle", "default", "Display", "Display",
                "Determine type of header menu.<br/>consists of: Default style, Group dropdown style, " +
                "Cascade dropdown style.", "", "Header Menu Style", true,
                Configuration.ConfigurationType.DropDown, "default|cascade|group",
                "Default|Cascade|Group", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "TodaySpecialModuleDisplay", "True", "Display", "Layout",
                "Enable or disable display Today’s Special.", "", "Today's Special", true,
                Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "CurrencyModuleDisplay", "True", "Display", "Layout",
                "Enable or disable currency drop down list.<br/>If disabled, the currency drop down list " +
                "will not be shown in the storefront.", "", "Currency", true,
                Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "NewsletterModuleDisplay", "True", "Display", "Layout",
                "Enable or disable newsletter box.<br/>If disabled, the newsletter box will not be shown " +
                "in the storefront.", "", "Newsletter", true,
                Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "InformationModuleDisplay", "True", "Display", "Layout",
                "Enable or disable information box.<br/>If disabled, the information box and associated links " +
                "will not be shown in the storefront.", "", "Information", false,
                Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "SpecialOfferModuleDisplay", "True", "Display", "Layout",
                "Enable or disable Special Offer.<br/>If disabled, the special offer will not be shown in the " +
                "storefront.", "", "Special Offer", true,
                Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "SpecialOfferImage", "Images/Configuration/specialoffer.png", "Display", "Layout",
                "Upload the special offer image here. ", "", "Special Offer Ad Image", true,
                Configuration.ConfigurationType.Upload, "", "", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "PaymentLogoModuleDisplay", "True", "Display", "Layout",
                "Enable or disable Payment Logo.<br/>If disabled, the payment logo will not be shown in the " +
                "storefront.", "", "Payment Logo", true,
                Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "PaymentLogoImage", "Images/Configuration/visa.gif", "Display", "Layout",
                "Merchants can upload the payment logo image here.", "", "Payment Logo Image", true,
                Configuration.ConfigurationType.Upload, "", "", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "SearchModuleDisplay", "True", "Display", "Layout",
                "Enable or disable Quick Search text box.", "", "Quick Search", true,
                Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "DisplayCategoryInQuickSearch", "True", "Display", "Layout",
                "If this option is enabled, the store will display category dropdown in quick search box.", "", "Display Category in Quick Search", true,
                Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "MiniCartModuleDisplay", "True", "Display", "Layout",
                "Enable or disable Mini Cart.", "", "Mini Cart", true,
                Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "CouponModuleDisplay", "True", "Display", "Layout",
                "Enable or disable Coupon box.<br/>If disable the coupon textbox will not be shown in the " +
                "storefront.", "", "Coupon", true, Configuration.ConfigurationType.DropDown,
                "True|False", "Yes|No", "", "", "", "CouponEnabled", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "FeaturedMerchantModuleDisplay", "True", "Display", "Layout",
                "Enable or disable Featured Merchant banners.", "", "Featured Merchant", true,
                Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
               ValueType.Single, CultureIDs.English,
               "FeaturedMerchantCount", "3", "Display", "Layout",
               "Number of Featured Merchants", "", "Number of Featured Merchants", true,
               Configuration.ConfigurationType.DropDown, "1|2|3", "1|2|3", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "FeaturedMerchantImage1", "Images/Configuration/merchant01.jpg", "Display", "Layout",
                "Merchants can also upload banners here.", "", "Featured Merchant Image 1", true,
                Configuration.ConfigurationType.Upload, "", "", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "FeaturedMerchantImage2", "Images/Configuration/merchant02.jpg", "Display", "Layout",
                "Merchants can also upload banners here.", "", "Featured Merchant Image 2", true,
                Configuration.ConfigurationType.Upload, "", "", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
               ValueType.Single, CultureIDs.English,
               "FeaturedMerchantImage3", "Images/Configuration/merchant03.jpg", "Display", "Layout",
               "Merchants can also upload banners here.", "", "Featured Merchant Image 3", true,
               Configuration.ConfigurationType.Upload, "", "", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "FeaturedMerchantUrl1", "", "Display", "Layout",
                "URL of Featured Merchant 1", "", "Featured Merchant URL 1", true,
                Configuration.ConfigurationType.TextBox, "", "", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "FeaturedMerchantUrl2", "", "Display", "Layout",
                "URL of Featured Merchant 2", "", "Featured Merchant URL 2", true,
                Configuration.ConfigurationType.TextBox, "", "", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "FeaturedMerchantUrl3", "", "Display", "Layout",
                "URL of Featured Merchant 3", "", "Featured Merchant URL 3", true,
                Configuration.ConfigurationType.TextBox, "", "", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "FreeShippingModuleDisplay", "True", "Display", "Layout",
                "Enable or disable Free Shipping Ad.", "", "Free Shipping Ad", true,
                Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "FreeShippingImage", "Images/Configuration/freeshipping.png", "Display", "Layout",
                "Merchants can also upload banners here.", "", "Free Shipping Ad Image", true,
                Configuration.ConfigurationType.Upload, "", "", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "SecureModuleDisplay", "True", "Display", "Layout",
                "Enable or disable Secure Shopping Ad.", "", "Secure Shopping Ad", true,
                Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "SecureImage", "Images/Configuration/secure.png", "Display", "Layout",
                "Merchants can also upload banners here.", "", "Secure Shopping Ad Image", true,
                Configuration.ConfigurationType.Upload, "", "", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "StoreBannerModuleDisplay", "True", "Display", "Layout",
                "Enable or disable display store banner.", "", "Store Banner", true,
                Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "StoreBannerEffectMode", "scrollLeft", "Display", "Layout",
                "Banner Sliding Effects (e.g. Random, Simple Fade, etc.).",
                "", "Sliding Effects", true,
                Configuration.ConfigurationType.DropDown,
                "none|random|simpleFade|curtainTopLeft|curtainTopRight|curtainBottomLeft|curtainBottomRight|curtainSliceLeft|curtainSliceRight|blindCurtainTopLeft|blindCurtainTopRight|blindCurtainBottomLeft|blindCurtainBottomRight|blindCurtainSliceBottom|blindCurtainSliceTop|stampede|mosaic|mosaicReverse|mosaicRandom|mosaicSpiral|mosaicSpiralReverse|topLeftBottomRight|bottomRightTopLeft|bottomLeftTopRight|bottomLeftTopRight|scrollLeft|scrollRight|scrollHorz|scrollBottom|scrollTop",
                "None|Random|Simple Fade|Curtain Top Left|Curtain Top Right|Curtain Bottom Left|Curtain Bottom Right|Curtain Slice Left|CurtainSlice Right|Blind Curtain Top Left|Blind Curtain Top Right|Blind Curtain Bottom Left|Blind Curtain Bottom Right|Blind Curtain Slice Bottom|Blind Curtain Slice Top|Stampede|Mosaic|Mosaic Reverse|Mosaic Random|Mosaic Spiral|Mosaic Spiral Reverse|Top Left Bottom Right|Bottom Right Top Left|Bottom Left Top Right|Bottom Left Top Right|Scroll Left|Scroll Right|Scroll Horz|Scroll Bottom|Scroll Top",
                "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "StoreBannerSlideSpeed", "5000", "Display", "Display",
                "Set milliseconds between the end of the sliding effect and the start of the nex one",
                "", "Length Of Banner Display (ms)", true,
                Configuration.ConfigurationType.TextBox, "", "", "", "", "", "", "Required|Integer", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "StoreBannerEffectPeriod", "1000", "Display", "Display",
                "Set length of the sliding effect in milliseconds", "", "Length Of Sliding Effect (ms)", true,
                Configuration.ConfigurationType.TextBox, "", "", "", "", "", "", "Required|Integer", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "BestsellersModuleDisplay", "True", "Display", "Layout",
                "Enable or disable Best Sellers.", "", "Bestsellers", true,
                Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "FeaturedProductModuleDisplay", "True", "Display", "Layout",
                "Enable or disable Feature Product.", "",
                "Featured Product ( Random Product )", true,
                Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "NewsModuleDisplay", "True", "Display", "Layout",
                "Enable or disable News and Announcement.", "", "News And Announcement", true,
                Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "GiftRegistryModuleDisplay", "False", "Display", "Layout",
                "If this option is disabled, the gift registry will not be shown in the store front.",
                "", " Gift Registry", true,
                Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "",
               "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "ProductSpecialEffectMode", "fade", "Display", "Layout",
                "Today’s Special Effects (e.g. Fade, Scroll Up, Scroll Left, etc.).",
                "", "Today's Special Effects", true,
                Configuration.ConfigurationType.DropDown,
                "none|fade|fadeZoom|blindX|blindY|blindZ|cover|uncover|curtainX|curtainY|growX|growY|scrollUp|scrollDown|scrollLeft|scrollRight|scrollHorz|scrollVert|shuffle|slideX|slideY|toss|turnUp|turnDown|turnLeft|turnRight|wipe|zoom",
                "None|Fade|Fade Zoom|Horizontal Blind|Vertical Blind|Z-Axis Blind|cover|Uncover|Horizontal Curtain|Verical Curtain|Horizontal Grow|Verical Grow|Scroll Up|Scroll Down|Scroll Left|Scroll Right|Scroll Horizontally|Scroll Vertically|Shuffle|Horizontal Slide|Vertical Slide|Toss|Turn Up|Turn Down|Turn Left|Turn Right|Wipe|Zoom",
                "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "ProductSpecialTransitionSpeed", "800", "Display", "Display",
                "Set image shuffling effect speed in milliseconds.",
                "", "Today's Special Transition speed (ms)", true,
                Configuration.ConfigurationType.TextBox, "", "", "", "", "", "", "Required|Integer", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "ProductSpecialEffectTimeout", "3000", "Display", "Display",
                "Set image displaying duration (in seconds).", "", "Today's Special Effect timeout", false,
                Configuration.ConfigurationType.TextBox, "", "", "", "", "", "", "Required|Integer", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "ProductSpecialEffectWaitTime", "1", "Display", "Display",
                "Today’s special setting.", "", "Today's Special Effect Wait time (s)", true,
                Configuration.ConfigurationType.TextBox, "", "", "", "", "", "", "Required|Integer", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "CategoryDynamicDropDownDisplay", "False", "Display", "Display",
                "Enable or disable Top Category Dynamic Drop-Down Menu",
                "", "Top Category Dynamic Drop-Down", true,
                Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "DepartmentDynamicDropDownDisplay", "False", "Display", "Display",
                "Enable or disable Top Department Dynamic Drop-Down Menu",
                "", "Top Department Dynamic Drop-Down", true,
                Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "ManufacturerDynamicDropDownDisplay", "False", "Display", "Display",
                "Enable or disable Top Manufacturer Dynamic Drop-Down Menu",
                "", "Top Manufacturer Dynamic Drop-Down", true,
                Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
            ValueType.Single, CultureIDs.English,
                "CategoryDynamicDropDownLevel", "5", "Display", "Display",
                "Determine maximum number of level of subcategories that can be displayed in " +
                "Top Category Dynamic Drop-Down Menu.", "", "Top Category Dynamic Drop-Down Menu Level", true,
                Configuration.ConfigurationType.TextBox, "", "", "", "",
                "", "", "Required|Integer", Store.Null.StoreID );

            CreateConfigConditionally(
            ValueType.Single, CultureIDs.English,
                "DepartmentDynamicDropDownLevel", "5", "Display", "Display",
                "Determine maximum number of level of subcategories that can be displayed in " +
                "Top Department Dynamic Drop-Down Menu.", "", "Top Department Dynamic Drop-Down Menu Level", true,
                Configuration.ConfigurationType.TextBox, "", "", "", "",
                "", "", "Required|Integer", Store.Null.StoreID );

            CreateConfigConditionally(
            ValueType.Single, CultureIDs.English,
                "RootCategory", "1", "System", "Display",
                "Set Root Category for selected store.",
                "", "Root Category", false, Configuration.ConfigurationType.DropDown, "", "", "", "",
                "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
            ValueType.Single, CultureIDs.English,
                "RootDepartment", "1", "System", "Display",
                "Set Root Department for selected store.",
                "", "Root Department", false, Configuration.ConfigurationType.DropDown, "", "", "", "",
                "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "AdvancedSearchMode", "Enhance", "System", "Display",
                "Set Advanced Search Mode", "", "Advanced Search Mode", true, Configuration.ConfigurationType.DropDown,
                "Classic|Enhance", "Classic|Enhance", "", "", "", "", "", Store.Null.StoreID );
        }

        private static void CreateCacheConfiguration()
        {
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "CatalogCachingEnabled", "True", "System", "Cache",
                "Enable cache for catalog items.", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "LanguageCachingEnabled", "True", "System", "Cache",
                "Enable cache for language text.", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "DiscountCachingEnabled", "True", "System", "Cache",
                "Enable cache for discount codes and quantity discount.", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "AdminCachingEnabled", "True", "System", "Cache",
                "Enable cache for Admin users and permissions.", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "CountryCachingEnabled", "True", "System", "Cache",
                "Enable cache for countries and states.", Store.Null.StoreID );
        }

        private static void CreatePaymentConfiguration()
        {
            CreateConfigConditionally( ValueType.Single,
                CultureIDs.English,
                "PaymentCurrency",
                "USD",
                "Payment",
                "Payment",
                "Base currency for this store to be used with payment gateway", Store.Null.StoreID );

            // Regular PayPal account details
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "PaymentByPayPalEmail", "Vevo@systems.com", "Payment", "Payment",
                "Email account of PayPal.", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "PaymentByPayPalEnvironment",
                "False",
                "Payment",
                "Payment",
                "Environment of PayPal.", Store.Null.StoreID );

            // PaySbuy account details begin
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "PaymentByPaySbuyEmail", "youremail@mail.com", "Payment", "Payment",
                "Email account of PaySbuy.", Store.Null.StoreID );
            // PaySbuy account details end

            // PayPal Pro API details
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "PayPalAPIUserName", "", "Payment", "Payment",
                "PayPal API UserName for using PayPal Pro payment gateway", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "PayPalAPIPassword", "", "Payment", "Payment",
                "PayPal API Password for using PayPal Pro payment gateway", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "PayPalAPISignature", "", "Payment", "Payment",
                "PayPal API Signature for using PayPal Pro payment gateway", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "PayPalEnvironment", "sandbox", "Payment", "Payment",
                "PayPal Environment for using PayPal Pro payment gateway", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "UseCustomTimeZone", "False", "Payment", "Payment",
                "Use TimeZone for startdate.", "", "Recurring Use Custom Time Zone", true,
                Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "CustomTimeZone", "0.0", "Payment", "Payment",
                "Use TimeZone for startdate.", "", "Time Zone", false, Configuration.ConfigurationType.DropDown,
                ("-12.00|-11.00|-10.00|-9.00|-8.00|-7.00|-6.00|-5.00|-4.00|-3.30|-3.00|-2.00|-1.00|0.00|" +
                "1.00|2.00|3.00|3:30|4.00|4:30|5.00|5:30|5:45|6.00|7.00|8.00|9.00|9.30|10.00|11.00|12.00"),
                ("(GMT -12:00) Eniwetok, Kwajalein|(GMT -11:00) Midway Island, Samoa|(GMT -10:00) Hawaii|" +
                "(GMT -9:00) Alaska|(GMT -8:00) Pacific Time (US &amp; Canada)|" +
                "(GMT -7:00) Mountain Time (US &amp; Canada)|" +
                "(GMT -6:00) Central Time (US &amp; Canada), Mexico City|" +
                "(GMT -5:00) Eastern Time (US &amp; Canada), Bogota, Lima|" +
                "(GMT -4:00) Atlantic Time (Canada), Caracas, La Paz|(GMT -3:30) Newfoundland|" +
                "(GMT -3:00) Brazil, Buenos Aires, Georgetown|(GMT -2:00) Mid-Atlantic|" +
                "(GMT -1:00 hour) Azores, Cape Verde Islands|" +
                "(GMT) Western Europe Time, London, Lisbon, Casablanca|" +
                "(GMT +1:00 hour) Brussels, Copenhagen, Madrid, Paris|(GMT +2:00) Kaliningrad, South Africa|" +
                "(GMT +3:00) Baghdad, Riyadh, Moscow, St. Petersburg|(GMT +3:30) Tehran|" +
                "(GMT +4:00) Abu Dhabi, Muscat, Baku, Tbilisi|(GMT +4:30) Kabul|" +
                "(GMT +5:00) Ekaterinburg, Islamabad, Karachi, Tashkent|" +
                "(GMT +5:30) Bombay, Calcutta, Madras, New Delhi|(GMT +5:45) Kathmandu|" +
                "(GMT +6:00) Almaty, Dhaka, Colombo|(GMT +7:00) Bangkok, Hanoi, Jakarta|" +
                "(GMT +8:00) Beijing, Perth, Singapore, Hong Kong|" +
                "(GMT +9:00) Tokyo, Seoul, Osaka, Sapporo, Yakutsk|(GMT +9:30) Adelaide, Darwin|" +
                "(GMT +10:00) Eastern Australia, Guam, Vladivostok|" +
                "(GMT +11:00) Magadan, Solomon Islands, New Caledonia|" +
                "(GMT +12:00) Auckland, Wellington, Fiji, Kamchatka"), "", "UseCustomTimeZone", "", "", "", Store.Null.StoreID );


            //Google checkout API details
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "GCheckoutChargeAuto", "True", "Gateway", "Google Checkout",
                "Enable charge at google checkout automate.", Store.Null.StoreID );

            // Custom payment options
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "PaymentByCustomList", "Check,Cash", "Payment", "Payment",
                "List payment by custom", Store.Null.StoreID );

            //KPayment option
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "KPaymentUrl",
                "",
                "Payment",
                "Payment",
                "Url for KPayment.", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "KPaymentMerchantID",
                "",
                "Payment",
                "Payment",
                "Merchant for KPayment.", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "KPaymentTerm",
                "",
                "Payment",
                "Payment",
                "TERM2 for KPayment", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "KPaymentRequestCardType",
                "True",
                "Payment",
                "Payment",
                "Request Cardtype of customer for KPayment.", Store.Null.StoreID );

            // 2Checkout Option
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "2COMerchantAccount",
                "xxxxxxx",
                "Payment",
                "Payment",
                "Merchant account of 2checkout", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "2COTestMode",
                "True",
                "Payment",
                "Payment",
                "Test payment for 2Checkout.", Store.Null.StoreID );

            // Authorize.Net Option
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "AuthorizeTestMode",
                "False",
                "Payment",
                "Payment",
                "Test Payment for Authorize.Net", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "AuthorizeLoginID",
                "xxx",
                "Payment",
                "Payment",
                "Login for Authorize.Net", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "AuthorizeTransectionKey",
                "xxx",
                "Payment",
                "Payment",
                "TransectionKey for Authorize.Net", Store.Null.StoreID );

            // eWay Payment
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "eWayCustomerID",
                "87654321",
                "Payment",
                "Payment",
                "CustomerID for eWayPayment", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "eWayUseCVN",
                "False",
                "Payment",
                "Payment",
                "Use number CVN with eWayPayment", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "eWayTest",
                "True",
                "Payment",
                "Payment",
                "Test for eWayPayment", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "eWayErrorCode",
                "00",
                "Payment",
                "Payment",
                "Error Response of eWay Payment for Test.", Store.Null.StoreID );

            // QBMS Payment
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "QbmsAppID",
                "",
                "Payment",
                "Payment",
                "AppID For QBMS merchant.", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "QbmsAppLogin",
                "",
                "Payment",
                "Payment",
                "AppLogin For QBMS merchant.", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "QbmsConnectionTicket",
                "",
                "Payment",
                "Payment",
                "Connection Ticket For QBMS merchant.", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "QbmsTest",
                "",
                "Payment",
                "Payment",
                "QBMS merchant test mode.", Store.Null.StoreID );

            // LinkPoint
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "LinkPointStoreNumber",
                "xxx",
                "Payment",
                "Payment",
                "Store Number for LinkPoint", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "LinkPointHost",
                "xxx",
                "Payment",
                "Payment",
                "Host for LinkPoint", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "LinkPointPort",
                "xxx",
                "Payment",
                "Payment",
                "Port for LinkPoint", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "LinkPointMode",
                "Good",
                "Payment",
                "Payment",
                "Mode for LinkPoint", Store.Null.StoreID );

            //Moneris Payment
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "PaymentByMoneris",
                "False",
                "Payment",
                "Payment",
                "Payment By Moneris", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "MonerisTestMode",
                "True",
                "Payment",
                "Payment",
                "Mode of Moneris.", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "MonerisStoreID",
                "",
                "Payment",
                "Payment",
                "Store_id kof Moneris", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "MonerisAPI_Token",
                "",
                "Payment",
                "Payment",
                "API_Token of Moneris", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "MonerisUseCVD",
                "False",
                "Payment",
                "Payment",
                "Use CVD with Moneris", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "MonerisCrypt",
                "7",
                "Payment",
                "Payment",
                "Crypt of Moneris", Store.Null.StoreID );

            //PayPalPro Express
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "PayPalProExpressEnvironment",
                "True",
                "Payment",
                "Payment",
                "PayPal Environment", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "PayPalProExpressUser",
                "",
                "Payment",
                "Payment",
                "PayPal User", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "PayPalProExpressPassword",
                "",
                "Payment",
                "Payment",
                "PayPal Password", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "PayPalProExpressSignature",
                "",
                "Payment",
                "Payment",
                "PayPal Signature", Store.Null.StoreID );

            //PayPal Pro UK
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "PayPalProUKTest",
                "",
                "Payment",
                "PayPalProUK",
                "Test mode", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "PayPalProUKUser",
                "",
                "Payment",
                "PayPalProUK",
                "User for paypal", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "PayPalProUKVender",
                "",
                "Payment",
                "PayPalProUK",
                "Vendor for paypal", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "PayPalProUKPartner",
                "",
                "Payment",
                "PayPalProUK",
                "Partner for paypal", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "PayPalProUKPassword",
                "",
                "Payment",
                "PayPalProUK",
                "Password for paypal", Store.Null.StoreID );

            // ProtX
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "ProtXMode",
                "TEST",
                "Payment",
                "ProtX",
                "Mode of ProtX", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "ProtXVendorName",
                "",
                "Payment",
                "ProtX",
                "Vendor Name of ProtX", Store.Null.StoreID );

            //RBSWorldpay
            CreateConfigConditionally(
               ValueType.Single,
               CultureIDs.English,
               "PaymentByRBSWorldPayInstId",
               "",
               "Payment",
               "RBSWorldpay",
               "Installation Id of RBSWorldpay.", Store.Null.StoreID );

            CreateConfigConditionally(
               ValueType.Single,
               CultureIDs.English,
               "PaymentByRBSWorldPayMode",
               "",
               "Payment",
               "RBSWorldpay",
               "Test result value of RBSWorldpay.", Store.Null.StoreID );

            //PayFlow
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "PayflowProUser",
                "",
                "Payment",
                "PayFlow Pro",
                "User", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "PayflowProVendor",
                "",
                "Payment",
                "PayFlow Pro",
                "Vender", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "PayflowProPartner",
                "",
                "Payment",
                "PayFlow Pro",
                "Partner", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "PayflowProPassword",
                "",
                "Payment",
                "PayFlow Pro",
                "Password", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "PayflowProTest",
                "True",
                "Payment",
                "PayFlow Pro",
                "Test", Store.Null.StoreID );
        }

        private static void CreateShippingConfiguration()
        {
            CreateConfigConditionally(
               ValueType.Single, CultureIDs.English,
               "ShippingMerchantCountry", "US", "Shipping", "Shipping",
               "Set merchant country to be used by your shipping option.<br/>This is the shipping origin country."
               , "", "Set Merchant Country", true,
               Configuration.ConfigurationType.UserControl, "", "", "", "",
               "Components/SiteConfig/ShippingMerchantCountry.ascx", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English, "ShippingIncludeDiscount", "True", "Shipping", "Shipping",
                "Discount will be included with sub total before calculate shipping cost<br/> " +
                "This option is only used for shipping by order total method.", "",
                "Include discount for calculate shipping by order total",
                true, Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "HandlingFeeEnabled", "False", "Shipping", "Shipping",
                "This option enables or disables handling fee.<br/>If disabled, the handling fee will not be " +
                "included in the transaction.", "", "Handling Fee Enabled", true,
                Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "RTShippingIgnoreFixedShippingCost",
                "False",
                "Shipping",
                "Shipping",
                "Ignore product fixed shipping cost for real-time shipping rates.", Store.Null.StoreID );

            //Shipping for Ups
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "RTShippingUpsUserID",
                "", "Shipping", "Ups",
                "User ID of Ups.", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "RTShippingUpsPassword",
                "", "Shipping", "Ups",
                "Password of Ups.", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "RTShippingUpsAccessLicenseNumber",
                "", "Shipping", "Ups",
                "AccessLicenseNumber of Ups.", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "RTShippingUpsService",
                "01,02", "Shipping", "Ups",
                "Use service of ups.", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "RTShippingUpsPickupType",
                "01",
                "Shipping", "Ups",
                "Set default Pickup Type", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "RTShippingUpsUseMinOrderWeight",
                "False", "Shipping", "Ups",
                "Use minimum order weight if total order weight is less", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "RTShippingUpsMinOrderWeight",
                "0.00", "Shipping", "Ups",
                "Use minimum order weight if total order weight is less", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "RTShippingUpsTestMode",
                "False", "Shipping", "Ups",
                "Use test shipping ups.", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "RTShippingUpsMerchantZip",
                "", "Shipping", "Ups",
                "Use merchant zip", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "RTShippingUpsMerchantCountry",
                "", "Shipping", "Ups",
                "Use merchant country", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "RTShippingUpsFreeShippingEnabled",
                "False", "Shipping", "Ups",
                "Use free shipping enable", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "RTShippingUpsFreeShippingCost",
                "0.00", "Shipping", "Ups",
                "Free shipping when buy product over limit.", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "RTShippingUpsFreeShippingService",
                "01,02", "Shipping", "Ups",
                "Service at free shipping when subtotal over limit.", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "RTShippingUpsMarkup",
                "0", "Shipping", "Ups",
                "Additional markup for UPS.", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "RTShippingUpsServiceAllowedSetFree",
                "0", "Shipping", "Ups",
                "Service that allowed set as free shipping cost per product", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "RTShippingUpsServiceAllowedUseCouponFree",
                "0", "Shipping", "Ups",
                "Service that allowed use with coupon free shipping cost", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "RTShippingUpsServiceNegotiatedRatesIndicator",
                "False", "Shipping", "Ups",
                "Request for Negotiated Rates", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "RTShippingUpsServiceShipperNumber",
                "", "Shipping", "Ups",
                "A UPS Account Number or Shipper Number is a unique six-digit reference number assigned by UPS to a shipper for billing purposes.",
                Store.Null.StoreID );
            //Shipping for FedEx
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "RTShippingFedExMerchantZip",
                "",
                "Shipping",
                "FedEx",
                "Use zip merchant", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "RTShippingFedExMerchantState",
                "",
                "Shipping",
                "FedEx",
                "Use state merchant", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "RTShippingFedExMerchantCountry",
                "",
                "Shipping",
                "FedEx",
                "Use country merchant", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "RTShippingFedExKey",
                "",
                "Shipping",
                "FedEx",
                "Web Service Key", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "RTShippingFedExPassword",
                "",
                "Shipping",
                "FedEx",
                "Web Service Password (Security Code)", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "RTShippingFedExAccountNumber",
                "",
                "Shipping",
                "FedEx",
                "Account Number", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "RTShippingFedExMeterNumber",
                "",
                "Shipping",
                "FedEx",
                "Meter Number", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "RTShippingFedExUrl",
                "https://gatewaybeta.fedex.com/web-services",
                "Shipping",
                "FedEx",
                "URL post for FedEx", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "RTShippingFedExServiceEnabled",
                "",
                "Shipping",
                "FedEx",
                "Use Filter Service", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "RTShippingFedExFreeShipping",
                "False",
                "Shipping",
                "FedEx",
                "Enable Free Shipping", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "RTShippingFedExFreeShippingCost",
                "0",
                "Shipping",
                "FedEx",
                "Use Free Shipping Cost", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "RTShippingFedExFreeShippingCostService",
                "",
                "Shipping",
                "FedEx",
                "Use Free Shipping Cost Service", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "RTShippingFedExDropoffType",
                "REGULAR_PICKUP",
                "Shipping",
                "FedEx",
                "Use Drop Of Type", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "RTShippingFedExPackingType",
                "YOUR_PACKAGING",
                "Shipping",
                "FedEx",
                "Use Packing Type", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "RTShippingFedExUseMinOrderWeight",
                "False",
                "Shipping",
                "FedEx",
                "Flag whether to set minimum weight to post to FedEx", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "RTShippingFedExMinOrderWeight",
                "0",
                "Shipping",
                "FedEx",
                "Minimum weight to post to FedEx", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "RTShippingFedExMarkup",
                "0",
                "Shipping",
                "FedEx",
                "Additional markup for FedEx", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "RTShippingFedExServiceAllowedSetFree",
                "0", "Shipping", "FedEx",
                "Service that allowed set as free shipping cost per product", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "RTShippingFedExServiceAllowedUseCouponFree",
                "0", "Shipping", "FedEx",
                "Service that allowed use with coupon free shipping cost", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "RTShippingFedExRateRequest",
                "account",
                "Shipping",
                "FedEx",
                "Select how to display shipping rate for FedEx", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "RTShippingFedExIncludeInsurance",
                "False",
                "Shipping",
                "FedEx",
                "Add Insurance Value/Declare Value to FedEx", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "RTShippingFedExCustoms",
                "False",
                "Shipping",
                "FedEx",
                "Include Customs Value to FedEx", Store.Null.StoreID );
            // Shipping for Usps
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "RTShippingUspsUserID",
                "",
                "Shipping",
                "Usps",
                "UserID for Usps", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "RTShippingUspsMerchantZip",
                "",
                "Shipping",
                "Usps",
                "Merchant Zip for Usps", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "RTShippingUspsMerchantCountryCode",
                "US",
                "Shipping",
                "Usps",
                "Merchant Country Code for Usps", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "RTShippingUspsUrl",
                "http://production.shippingapis.com/ShippingAPI.dll",
                "Shipping",
                "Usps",
                "URL post for Usps", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "RTShippingUspsMailType",
                "Package",
                "Shipping",
                "Usps",
                "MailType for Usps", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "RTShippingUspsServiceEnabledList",
                "",
                "Shipping",
                "Usps",
                "Service enabled for Usps", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "RTShippingUspsIsFreeShipping",
                "False",
                "Shipping",
                "Usps",
                "Use free shipping for Usps", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "RTShippingUspsFreeShippingCost",
                "0",
                "Shipping",
                "Usps",
                "Free shipping cost for Usps", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "RTShippingUspsServiceFreeShipping",
                "False",
                "Shipping",
                "Usps",
                "Service free shipping for Usps", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "RTShippingUspsIsMinWeight",
                "False",
                "Shipping",
                "Usps",
                "Use minimum weight per order if weight total for each order lower than user define for Usps", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "RTShippingUspsMinWeightOrder",
                "",
                "Shipping",
                "Usps",
                "Minimum weight per order for Usps", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "RTShippingUspsMarkUpPrice",
                "0",
                "Shipping",
                "Usps",
                "Markup Price for Usps", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "RTShippingUspsServiceAllowedSetFree",
                "0", "Shipping", "Usps",
                "Service that allowed set as free shipping cost per product", Store.Null.StoreID );
            CreateConfigConditionally(
               ValueType.Single,
               CultureIDs.English,
               "RTShippingUspsServiceAllowedUseCouponFree",
               "0", "Shipping", "Usps",
               "Service that allowed use with coupon free shipping cost", Store.Null.StoreID );
        }

        private static void CreateTaxConfiguration()
        {
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "TaxPercentage", "0", "Main", "Tax",
                "Percentage of tax to be added to the product price.", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "TaxRule", "1", "Configuration", "Payment",
                "1 : Apply tax everywhere in the world. (Default), " +
                "2 : Apply tax only in the specific country., " +
                "3 : Apply tax only in the specific state (US only)", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "TaxLocation", "", "Configuration", "Payment",
                "Value country or state of taxrate.", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "IsTaxableWholesaler", "True", "System", "Tax",
                "If this option is enabled, tax will be calculated to users flagged as “Wholesaler”.",
                "", "Wholesalers are Taxable", true,
                Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "IsTaxableShippingCost", "False", "System", "Tax",
                "If this option is enabled, tax will be applied to shipping costs and handling fees.",
                "", "Shipping Cost is Taxable.", true,
                Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "ShippingTaxClass", "0", "System", "Tax",
                "Set the tax class to calculate tax rate of the shipping cost.", "", "Shipping Tax Class", false,
                Configuration.ConfigurationType.DropDown, "", "", "", "IsTaxableShippingCost", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "TaxIncludedInPrice", "False", "System", "Tax",
                "If this option is enabled, the product price that the merchant has entered<br />in the Admin " +
                "website will be treated as tax included. This is useful for<br />some countries that use " +
                "VAT system.", "", "Price already includes tax", true,
                Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "TaxPriceAfterDiscount", "False", "System", "Tax",
                "If this option is enables, tax will be calculated after the discount has been<br />applied " +
                "to the product cost. In general, this means that tax will reduced<br/>with the discount if " +
                "this option is enabled.", "", "Calculate tax after applying discount",
                true, Configuration.ConfigurationType.DropDown,
                "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "TaxPercentageIncludedInPrice", "0", "System", "Tax",
                "Set the percentage of tax rate that including in display price.",
                "", "Tax Percentage Include in price (%)", false,
                Configuration.ConfigurationType.TextBox, "", "", "", "TaxIncludedInPrice", "", "",
                "Required|Double1,100", Store.Null.StoreID );

        }

        private static void CreateCompanyConfiguration()
        {
            CreateConfigConditionally(
                ValueType.MultiCulture,
                CultureIDs.English,
                "Title", "ABC Store Online", "Company", "Company",
                "Website title.", Store.Null.StoreID );
            UpdateValueConditionally(
                CultureIDs.Thai,
                "Title",
                "ร้าน เอบีซี ออนไลน์", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.MultiCulture,
                CultureIDs.English,
                "CompanyName", "ABC Inc.", "Company", "Company",
                "Name of your business.", Store.Null.StoreID );
            UpdateValueConditionally(
                CultureIDs.Thai,
                "CompanyName",
                "บริษัท เอบีซี จำกัด", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.MultiCulture,
                CultureIDs.English,
                "CompanyAddress", "1234 First Street", "Company", "Company",
                "Street address of your business.", Store.Null.StoreID );
            UpdateValueConditionally(
                CultureIDs.Thai,
                "CompanyAddress",
                "1234 ถนน เฟริสท์", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.MultiCulture,
                CultureIDs.English,
                "CompanyCity", "Los Angeles", "Company", "Company",
                "City of your business.", Store.Null.StoreID );
            UpdateValueConditionally(
                CultureIDs.Thai,
                "CompanyCity",
                "ลอสแองเจลิส", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.MultiCulture,
                CultureIDs.English,
                "CompanyState", "CA", "Company", "Company",
                "State (address) of your business.", Store.Null.StoreID );
            UpdateValueConditionally(
                CultureIDs.Thai,
                "CompanyState",
                "แคลิฟอร์เนีย", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "CompanyZip", "90300", "Company", "Company",
                "Zip code of your business.", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.MultiCulture,
                CultureIDs.English,
                "CompanyCountry", "USA", "Company", "Company",
                "Country of your business.", Store.Null.StoreID );
            UpdateValueConditionally(
                CultureIDs.Thai,
                "CompanyCountry",
                "สหรัฐอเมริกา", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "CompanyPhone", "850-382-3948", "Company", "Company",
                "Phone number of your business.", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "CompanyFax", "850-382-3949", "Company", "Company",
                "Fax number of your business.", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "CompanyEmail", "contactabc@127.0.0.1", "Company", "Company",
                "Contact email of your business.", Store.Null.StoreID );
        }

        private static void CreateGiftCertificateConfiguration()
        {
            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "GiftRedeemProductOnly", "True", "GiftCertificate", "GiftCertificate",
                "If this option is set to “Yes”, gift certificate can only redeem product cost," +
                "not tax and shipping cost.", "", "Redeem product cost only (no tax and shipping)", true,
                Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "GiftCertificateEnabled", "True", "GiftCertificate", "GiftCertificate",
                "his option enables or disables gift certificate.<br />If disabled, this gift certificate boxes " +
                "and links will not be shown to customers.<br />So, they will not be able to use " +
                "gift certificates for this store.", "", "Gift Certificate Enabled", true,
                Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

        }

        private static void CreateProductImageConfiguration()
        {
            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "RegularImageWidth", "350", "ProductImage", "ProductImage",
                "This option sets the regular image width. The website default is 350.<br/>This is the width " +
                "that shows in the product detail page.", "", "Regular Image Width", true,
                Configuration.ConfigurationType.TextBox, "", "", "", "", "", "", "Integer", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "SecondaryImageWidth", "100", "ProductImage", "ProductImage",
                "This option sets the secondary image width. The website default is 100.<br/>This is the width " +
                "that shows in product listing, category listing, and department listing page.", "", "Secondary Image Width", true,
                Configuration.ConfigurationType.TextBox, "", "", "", "", "", "", "Integer", Store.Null.StoreID );
        }

        private static void CreateTrackingUrl()
        {
            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "UpsTrackingUrl", "http://wwwapps.ups.com/WebTracking/processInputRequest?tracknum=[TrackNum]",
                "TrackingUrl", "TrackingUrl", "Set UPS tracking URL to view package tracking information.",
                "", "UPS", true,
                Configuration.ConfigurationType.TextBox, "", "", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "FedExTrackingUrl", "http://www.fedex.com/Tracking?tracknumbers=[TrackNum]",
                "TrackingUrl", "TrackingUrl", "Set FedEx tracking URL to view package tracking information.",
                "", "FedEx", true,
                Configuration.ConfigurationType.TextBox, "", "", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "UspsTrackingUrl",
                "http://trkcnfrm1.smi.usps.com/PTSInternetWeb/InterLabelInquiry.do?origTrackNum=[TrackNum]",
                "TrackingUrl", "TrackingUrl", "Set USPS tracking URL to view package tracking information.",
                "", "USPS", true,
                Configuration.ConfigurationType.TextBox, "", "", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "OtherTrackingUrl", "", "TrackingUrl", "TrackingUrl",
                "Set other tracking URL to view package tracking information.<br/>This field is for your " +
                "own use for the shipping gateway that we do not support.",
                "", "Other", true,
                Configuration.ConfigurationType.TextBox, "", "", "", "", "", "", "", Store.Null.StoreID );
        }

        private static void CreateGoogleAnalytics()
        {
            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "GoogleAnalyticsEnabled", "False", "Display", "Display",
                "Enable or disable Google analytics.", "", "Google Analytics Enabled", true,
                Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "GoogleAnalyticsAccount", "", "Display", "Display",
                "This is the Google analytics Tracking ID. It should be in the number format, such as UA-XXXXXXXX-X.", "", "Google Analytics Tracking ID", true,
                Configuration.ConfigurationType.TextBox, "", "", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "GoogleAnalyticsCustomCodeEnabled", "False", "Display", "Display",
                "Enable or disable custom javacript code of Google analytics.", "", "Google Analytics Custom Code Enabled", true,
                Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "GoogleAnalyticsCustomCode", "", "Display", "Display",
                "This is the Google analytics javascript custom code.<br/>It should be code which generared from Google.",
                "", "Google Analytics Custom Code", true,
                Configuration.ConfigurationType.TextBox, "", "", "", "", "", "", "",
                Store.Null.StoreID );
        }

        private static void CreateEmailNotification()
        {
            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "NotifyNewRegistration", "False", "System", "System",
                "Enable or disable send email notification to new customers after registration finishes." +
                "<br/>If disabled, the email notification will not be sent to new customers.", "",
                "New Customer Registration", true,
                Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "AdminAdvancedFolder",
                "AdminAdvanced",
                "System", "System",
                "Admin advance folder.", Store.Null.StoreID );
        }

        private static void CreateSecurityConfiguration()
        {
            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "EnableSSL", "False", "System", "Security",
                "Select &ldquo;Yes&rdquo; to enable SSL for your store. Your web server is required to " +
                "subscribe to<br />SSL service provider such as Verisign.com. If this option is selected, " +
                "data encryption<br />will be used during the checkout process. Specifically, the following " +
                "pages will<br />automatically use SSL to transfer data:Payment.aspx , OrderSummary.aspx<br />" +
                "CheckoutComplete.aspx , DirectPaymentSale.aspx and Shipping.aspx",
                "", "Enable SSL during login & checkout", true,
                Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "EnableAdminSSL", "False", "System", "Security",
                "Select “Yes” to enable SSL for your store. Your web server is required to<br/>" +
                "subscribe to SSL service provider such as Verisign.com. If this option is<br/>selected, " +
                "data encryption will be used to the entire admin page.",
                "", "Enable SSL for Admin Panel", true,
                Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );
        }

        private static void CreateMiscConfiguration()
        {
            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "WeightUnit", "LB", "Shipping", "Shipping",
                "Unit of weight can be either in pound (LB) or kilogram (KG).", "", "Unit of Weight", true,
                Configuration.ConfigurationType.DropDown, "LB|KG", "LB|KG", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "ProductSearchBy",
                "Name,ShortDescription,LongDescription,Keywords",
                "ProductSearch", "Enable",
                "Display Search Product", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "OrderStatusList",
                "New, Waiting Payment, Shipped", "Order", "Order",
                "List of order status", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "DefaultWebsiteLanguage", "en-US", "System", "Language",
                "Choose your language for your website.<br />" +
                "To see the effect of this setting,<br />" +
                "please close and re-open the browser to start a new browsing session.", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "LanguageKeywordBaseCulture",
                "en-US",
                "System",
                "Language",
                "This is the fallback language for the keyword that is undefined.<br /> For example, " +
                "suppose that a customer views a page in Chinese and<br />the language keyword [$Date] " +
                "was not defined in Chinese.<br />Instead of displaying &ldquo;[$Date]&rdquo;, the system " +
                "will try searching for [$Date] keyword<br />in the base language.", Store.Null.StoreID );

            CreateConfigConditionally(
               ValueType.Single, CultureIDs.English,
               "LanguageMenuDisplayMode", "DropDown", "System", "Language",
               "The value can be either Horizontal or Drop-Down.<br/> The horizontal menu will display names " +
               "of supported languages horizontally.<br/> The drop-down option will cause the languages to be " +
               "displayed in a drop-down menu.", "", "Language Menu Display Mode", true,
               Configuration.ConfigurationType.DropDown, "None|Horizontal|DropDown", "(None)|Horizontal|DropDown",
               "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "UrlCultureName", "en-US", "System", "Language",
                "This option is used in conjunction with the previous option.<br />This option will set the " +
                "language to use in URL for product, category and department names.<br />This option will affect only the " +
                "products that has been added or updated<br />after setting this configuration.",
                "", "URL Language", false,
                Configuration.ConfigurationType.DropDown, "", "", "", "UseSimpleCatalogUrl", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
              ValueType.Single, CultureIDs.English,
              "BaseWebsiteCurrency", "USD", "System", "Currency",
              "Set default base currency on your website.", "", "Set Default Currency", true,
              Configuration.ConfigurationType.DropDown, "", "", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "DefaultDisplayCurrencyCode", "USD", "System", "Currency",
                "Set default currency to be displayed on your store.", "", "Default Display Currency Code", true,
                Configuration.ConfigurationType.DropDown, "", "", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "BaseWebsiteCurrencySymbol", "$", "System", "Currency",
                "Default Currency symbol for displaying in front page", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "UseSimpleCatalogUrl", "True", "Main", "Main",
                "If enabled, the names of products and categories will be used<br />in the URL to help SEO. " +
                "If disabled, URL will show product/category/department ID.", "",
                "SEO-Friendly Product URL", true, Configuration.ConfigurationType.DropDown,
                "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "ShippingAddressMode", "True", "System", "Display",
                "If this option is set to &ldquo;No&rdquo;, your store will not ask customers<br />" +
                "for shipping addresses during checkout. <br />You should set to &ldquo;No&rdquo; only if your " +
                "products do not require<br />physical shipment, e.g. e-Goods.",
                "", "Required Shipping Address", true,
                Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "IsDiscountAllCustomer", "True", "System", "Discount",
                "This setting must be set to “Yes” if you would like to use Quantity Discount feature.",
                "", "Use discount rule with all customers", true,
                Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "QuantityDiscountHistory",
                "False",
                "System",
                "Discount",
                "Quantity-based Discount Uses Order History.", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "OrderMaximumEnabled",
                "False",
                "System",
                "Merchant",
                "Enable and Disable Maximum Amount", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "OrderMaximumAmount",
                "0",
                "System",
                "Merchant",
                "Effective if “Limit maximum order amount” is set to “Yes”. This is the maximum<br/> " +
                "order amount that customer is allowed to purchase in one transaction.", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "OrderMinimumEnabled",
                "False",
                "System",
                "Merchant",
                "Enable and Disable Minimum Amount", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "OrderMinimumAmount",
                "0",
                "System",
                "Merchant",
                "Effective if “Limit minimum order amount” is set to “Yes”. This is the minimum<br/>" +
                "order amount that customer is allowed to purchase in one transaction.", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "UploadExtension", "jpg,gif,zip,rar", "Configuration", "Upload",
                "This is the list of file extensions that could be uploaded for Upload Product Option." +
                "<br/>The extensions can be separated by commas (,).", "", "Extension allow", true,
                Configuration.ConfigurationType.TextBox, "", "", "", "", "", "", "Required", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "UploadSize", "4000", "Configuration", "Upload",
                "The maximum size of the files that can be uploaded. This is for Upload Product Option.",
                "", "Max size (kb).", true,
                Configuration.ConfigurationType.TextBox, "", "", "", "", "", "", "Required|Integer", Store.Null.StoreID );

            CreateConfigConditionally(
              ValueType.Single, CultureIDs.English,
              "PaymentAppUrl", "~/PaymentModule", "Payment", "Payment",
              "The URL of Payment Application.",
              "", "Payment Application URL", true,
              Configuration.ConfigurationType.TextBox, "", "", "", "", "", "VevoPayPADSSMode", "Required", Store.Null.StoreID );

            CreateConfigConditionally(
              ValueType.Single, CultureIDs.English,
              "PaymentSSLEnabled", "False", "Payment", "Payment",
              "Select “Yes” to use secure connection (SSL) for communication with payment application.",
              "", "Payment SSL Enabled", true,
              Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "VevoPayPADSSMode", Store.Null.StoreID );

            CreateConfigConditionally(
              ValueType.Single, CultureIDs.English,
              "VevoPayPADSSMode", "False", "Payment", "Payment",
              "Select “Yes” to use payment with PA-DSS Certified",
              "", "Use VevoPay PA-DSS Mode", true,
              Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
              ValueType.Single,
              CultureIDs.English,
              "HtmlEditor", "Html", "System", "Display",
              "<div>This setting is to choose whether to use HTML text editor. It will affect a few " +
              "places where HTML<br />editor can be used in both storefront and back office, e.g. " +
              "Tell-A-Friend and Admin Product Edit.<br /></div><div>Set &ldquo;HTML&rdquo; to use " +
              "HTML editor. Some of the browsers may not support &ldquo;FreeTextBox&rdquo;, which is<br />" +
              "the editor that we use for HTML text editing. In that case, you should set to " +
              "&ldquo;PlainText&rdquo;. <br />Currently, Internet Explorer 8 and Google Chrome do not " +
              "support FreeTextBox.</div>", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "ShowDetailAjaxErrorMessage", "False", "System", "Display",
                "By default, error message from Ajax-enabled page will be shown as a brief<br/> summary. " +
                "To troubleshoot a problem, you may enable this option to show<br/>detailed error message.",
                "", "Show detailed error messages for Ajax", true,
                Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "ThubLogEnabled", "False", "System", "System",
                "Enabled or disable to save log file when export data with T-Hub", "", "Enable T-Hub Log", true,
                Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "DownloadExpirePeriod", "30", "System", "System",
                "This option is used for e-Goods.It indicates how many days that<br />the download link for " +
                "e-Goods will be expired after being purchased.", "", "Download Link Expiration (day)", true,
                Configuration.ConfigurationType.TextBox, "", "", "", "", "", "",
                "Integer", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "IsUnlimitDownload", "True", "System", "System",
                "Download Count", "", "Download Count", true, Configuration.ConfigurationType.UserControl,
                "", "", "", "", "Components/SiteConfig/DownloadCountConfig.ascx", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "NumberOfDownloadCount", "", "System", "System",
                "Number of Download Count", "", "Number of Download Count",
                false, Configuration.ConfigurationType.UserControl,
                "", "", "", "IsUnlimitDownload", "Components/SiteConfig/DownloadCountConfig.ascx", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "AnonymousCheckoutAllowed", "False", "System", "System",
                "Enable or disable anonymous checkout.<br/>Please see “Anonymous Checkout” section in " +
                "the User Manual for more details.", "", "Allow Anonymous Checkout", true,
                Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "ContentSearchBy", "ContentName,Title,Body,MetaTitle,MetaKeyword,MetaDescription",
                "ContentSearch", "Enable", "Display Search Content", Store.Null.StoreID );

            CreateConfigConditionally(
              ValueType.Single,
              CultureIDs.English,
              "TopContentMenu", "2", "ContentMenu", "ContentMenu",
              "TopContentMenu Root ID.", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "LeftContentMenu", "3", "ContentMenu", "ContentMenu",
                "LeftContentMenu Root ID.", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "RightContentMenu", "4", "ContentMenu", "ContentMenu",
                "RightContentMenu Root ID.", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single,
                CultureIDs.English,
                "TopContentMenuType", "default", "ContentMenu", "ContentMenu",
                "TopContentMenu Type", Store.Null.StoreID );

            CreateConfigConditionally(
               ValueType.Single,
               CultureIDs.English,
               "LeftContentMenuType", "default", "ContentMenu", "ContentMenu",
               "LeftContentMenu Type", Store.Null.StoreID );

            CreateConfigConditionally(
               ValueType.Single,
               CultureIDs.English,
               "RightContentMenuType", "default", "ContentMenu", "ContentMenu",
               "RightContentMenu Type", Store.Null.StoreID );

            CreateConfigConditionally(
               ValueType.Single,
               CultureIDs.English,
               "GoogleSitemapsIsIncludesCategories",
               "True",
               "Google xml sitemaps", "Google xml sitemap",
               "include categories in xml sitemap", Store.Null.StoreID );

            CreateConfigConditionally(
               ValueType.Single,
               CultureIDs.English,
               "GoogleSitemapsIsIncludesProducts",
               "True",
               "Google xml sitemaps", "Google xml sitemaps",
               "include products in xml sitemaps", Store.Null.StoreID );

            CreateConfigConditionally(
               ValueType.Single,
               CultureIDs.English,
               "GoogleSitemapsIsIncludesContents",
               "True",
               "Google xml sitemap", "Google xml sitemaps",
               "include content pages in xml sitemaps", Store.Null.StoreID );

            CreateConfigConditionally(
               ValueType.Single,
               CultureIDs.English,
               "GoogleSitemapsChangeFrequency",
               "weekly",
               "Google xml sitemaps", "Google xml sitemaps",
               "set default ChangeFrequency parameter", Store.Null.StoreID );

            CreateConfigConditionally(
               ValueType.Single,
               CultureIDs.English,
               "GoogleSitemapsURLPriority",
               "0.5",
               "Google xml sitemaps", "Google xml sitemaps",
               "set default url priority parameter", Store.Null.StoreID );

        }

        private static void CreateAffiliateConfiguration()
        {
            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "AffiliateEnabled", "False", "System", "Affiliate",
                "Enable or disable affiliate system.", "", "Affiliate Enabled", true,
                Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "AffiliateAutoApprove", "False", "System", "Affiliate",
                "If this setting is &ldquo;Yes&rdquo;, when a user applies for the affiliate program," +
                "<br />he/she will be approved as an affiliate automatically.<br />If this setting is " +
                "&ldquo;No&rdquo;, the merchant will receive an notification email <br />when a user has " +
                "applied and need to approve the user manually in the back office.", "", "Affiliate Auto Approve", true,
                Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "AffiliateReference", "First", "System", "Affiliate",
                "A customer may follow more than affiliate links to your website (e.g. from affiliate banner" +
                "<br />of one website and a directory link from another website). This option determines <br />" +
                "which affiliate will get credit and commission for this customer.<br />&middot;&nbsp;&nbsp;" +
                "&nbsp;&nbsp; Always use first affiliate &ndash; this option will credit the first referring " +
                "affiliate <br />for any purchase for this customer.<br />&middot;&nbsp;&nbsp;&nbsp;&nbsp; " +
                "Use latest affiliate &ndash; this option will credit the most recent affiliate.",
                "", "In case of multiple affiliate references", true,
                Configuration.ConfigurationType.DropDown, "First|Last",
                "Always use first affiliate|use latest affiliate", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "AffiliateCommissionRate", "10", "System", "Affiliate",
                "The default commission rate when a new affiliate has registered on your website. <br />The " +
                "commission rate for each affiliate can be edited in Affiliate List menu<br />" +
                "in the Admin website.", "", "Default Commission Rate (%)", true,
                Configuration.ConfigurationType.TextBox, "", "", "", "", "", "",
                "Double", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "AffiliateExpirePeriod", "60", "System", "Affiliate",
                "Set how many days that affiliate cookie will be expired.After the cookie is expired for that " +
                "customer,<br />the affiliate will no longer receive any commission for that customer&rsquo;s " +
                "purchases.", "", "Cookie Expire Period (days)", true,
                Configuration.ConfigurationType.TextBox, "", "", "", "", "", "",
                "Integer", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "AffiliateDefaultPaidBalance", "100", "System", "Affiliate",
                "Some merchants will redeem commissions to an affiliate only<br />if the accumulated " +
                "commissionsbalance for that affiliate has reached certain threshold.<br />The &ldquo; " +
                "Affiliate Payment&rdquo; menu in the Admin website will only display the list of affiliates" +
                "<br />that have balances equal to or above this setting. This &ldquo;Default Paid " +
                "Balance&rdquo; value <br />must be greater than zero.", "", "Default Paid Balance", true,
                Configuration.ConfigurationType.TextBox, "", "", "", "", "", "",
                "Double", Store.Null.StoreID );
        }

        private static void CreateQuickBooksConfiguration()
        {
            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "QBIncomeAccountName", "Sales", "System", "System",
                "The income account for gross receipts to the QuickBook", "", "Account Name", false,
                Configuration.ConfigurationType.TextBox, "", "", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "QBTaxItem", "Online Tax", "System", "System",
                "The tax item use to calculate sales tax", "", "Tax Item", false,
                Configuration.ConfigurationType.TextBox, "", "", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "QBDiscountItem", "Discounts", "System", "System",
                "The discount item for subtract from total or subtotal", "", "Discount Item", false,
                Configuration.ConfigurationType.TextBox, "", "", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "QBShippingItem", "Shipping Charges", "System", "System",
                "The discount item for subtract from total or subtotal", "", "Shipping Item", false,
                Configuration.ConfigurationType.TextBox, "", "", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "QBCustomerNameFormat", "firstlast", "System", "System",
                "Select customer name format for display in order", "", "Customer Name Format", false,
                Configuration.ConfigurationType.DropDown, "firstlast|lastfirst",
                "Firstname Lastname|Lastname, Firstname", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "QBVevoAdminUser", "admin", "System", "System",
                "VevoCart account with administrator privileges to sync data", "", "Admin Account", false,
                Configuration.ConfigurationType.TextBox, "", "", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "QBSelectStoreExport", "", "System", "System",
                "Select store name for sync data with QuickBook", "", "Store Name", false,
                Configuration.ConfigurationType.DropDown, "", "", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "QBEnableCustomerModify", "False", "System", "System",
                "Enable VevoCart sent update customer information to Quickbook", "", "Enable update customer", false,
                Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "QBEnableProductModify", "False", "System", "System",
                "Enable VevoCart sent update product information to Quickbook", "", "Enable update product", false,
                Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "QBAnonymousListID", "", "System", "System", "QuickBooks: Set ListID for Anonymous user", Store.Null.StoreID );
        }

        private static void CreateWebServiceConfiguration()
        {
            CreateConfigConditionally(
                 ValueType.Single, CultureIDs.English,
                 "WebServiceAdminUser", "admin", "System", "System",
                 "VevoCart account with administrator privileges to use web service", "", "Web Service Admin Account", false,
                 Configuration.ConfigurationType.TextBox, "", "", "", "", "", "", "", Store.Null.StoreID );
        }

        private static void CreateeBayConfiguration()
        {
            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "eBayConfigDevID", "", "System", "eBay",
                "eBay unique identifier for the developer (or company) account.<br/>Get this ID in \"My Account\" section on eBay site.",
                "", "eBay DevID", true,
                Configuration.ConfigurationType.TextBox, "", "", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "eBayConfigAppID", "", "System", "eBay",
                "eBay unique identifier for the application.<br/>Get this ID in \"My Account\" section on eBay site.",
                "", "eBay AppID", true,
                Configuration.ConfigurationType.TextBox, "", "", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "eBayConfigCertID", "", "System", "eBay",
                "eBay certificate that authenticates the application when making API calls.<br/>Get this ID in \"My Account\" section on eBay site.",
                "", "eBay CertID", true,
                Configuration.ConfigurationType.TextBox, "", "", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "eBayConfigToken", "", "System", "eBay",
                "An authorization for your application to access eBay data on behalf of an eBay user.<br/>Get this token by using generate tool \"Get a User Token\" in eBay developer site.",
                "", "eBay Token", true,
                Configuration.ConfigurationType.TextBox, "", "", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "eBayConfigListingMode", "https://api.sandbox.ebay.com/wsapi", "System", "eBay",
                "eBay listing site. Sandbox mode is a testing site. Production mode is a live site",
                "", "eBay Listing Mode", true,
                Configuration.ConfigurationType.DropDown,
                "https://api.sandbox.ebay.com/wsapi|https://api.ebay.com/wsapi",
                "Sandbox|Production", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "eBayOrderLastestUpdateTime", "", "System", "eBay",
                "Latest eBay order update time",
                "", "Lastest eBay order update time", false,
                Configuration.ConfigurationType.TextBox,
                "", "", "", "", "", "", "", Store.Null.StoreID );
        }

        private static void CreareFacebookConfiguration()
        {
            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "FacebookLoginEnabled", "False", "System", "Facebook",
                "Enable or disable Facebook login button", "", "Enabled Facebook Login Button", true,
                Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "FacebookAPIKey", "", "System", "Facebook",
                "Facebook unique identifier for the application.<br/>Get this key in \"Setting\" section on Facebook developers page.",
                "", "App ID/API key", true,
                Configuration.ConfigurationType.TextBox,
                "", "", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "FacebookAppSecret", "", "System", "Facebook",
                "Facebook secret key for the application.<br/>Get this code in \"Setting\" section on Facebook developers page.",
                "", "App Secret", true,
                Configuration.ConfigurationType.TextBox,
                "", "", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "FacebookAccessToken", "", "System", "Facebook",
                "Facebook token for access to the application.<br/>Get this token in \"Setting\" section on Facebook developers page.",
                "", "Access Token", true,
                Configuration.ConfigurationType.TextBox,
                "", "", "", "", "", "", "", Store.Null.StoreID );

        }

        private static void CreatePointSystemConfiguration()
        {
            CreateConfigConditionally( ValueType.Single, CultureIDs.English, "PointSystemEnabled", "False", "System", "Point System",
                "Enable or disable Point System", "", "Enabled Point System", true,
                Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );
            CreateConfigConditionally( ValueType.Single, CultureIDs.English, "RewardPoints", "0", "System", "Point System",
                "These the reward points awarded to customer per money spent.", "", "Reward Points", true,
                Configuration.ConfigurationType.TextBox, "", "", "", "", "", "", "", Store.Null.StoreID );
            CreateConfigConditionally( ValueType.Single, CultureIDs.English, "PointValue", "0", "System", "Point System",
                "These is the number that each point is worth", "", "Point Value", true,
                Configuration.ConfigurationType.TextBox, "", "", "", "", "", "", "", Store.Null.StoreID );
        }

        private static void CreateBlogConfiguration()
        {
            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "BlogEnabled", "False", "System", "Blog",
                "Enable or disable blog", "", "Enabled Blog", true,
                Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "BlogListItemsPerPage", "6", "System", "Blog",
                "This is the number of blog to show in blog list page.<br />This is the list of numbers " +
                "separating by comma (ex. 1, 3, 5, 7). <br />The first value will be the default value.<br />" +
                "These values are selectable in the drop down list in the product list page.",
                "", "Number of displayed blogs", true,
                Configuration.ConfigurationType.TextBox, "", "", "", "", "", "", "", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.MultiCulture,
                CultureIDs.English,
                "BlogPageTitle", "Blog Title", "System", "Blog",
                "This setting will be shown on title bar.", Store.Null.StoreID );
            UpdateValueConditionally(
                CultureIDs.Thai,
                "BlogPageTitle",
                "วีโวคาร์ท บล็อค", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "BlogTheme", "BlogTheme", "Display", "Blog",
                "This is blog theme setting.", "", "Blog Theme", true,
                Configuration.ConfigurationType.UserControl, "", "", "", "",
                "Components/SiteConfig/LayoutBlogThemeSelect.ascx", "", "", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "DefaultBlogListLayout", "BlogListRowStyle.ascx", "Display", "Blog",
                "This is default layout of blog list display.", "", "Blog List Default layouts", true,
                Configuration.ConfigurationType.UserControl, "", "", "", "",
                "Components/SiteConfig/LayoutBlogListSelect.ascx", "", "", Store.Null.StoreID );
            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "DefaultBlogDetailsLayout", "BlogDetailsDefault.ascx", "Display", "Blog",
                "This is default layout of blog details display.", "", "Blog Details Default layouts", true,
                Configuration.ConfigurationType.UserControl, "", "", "", "",
                "Components/SiteConfig/LayoutBlogDetailsSelect.ascx", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                 ValueType.Single, CultureIDs.English,
                 "FacebookCommentEnabled", "False", "System", "Facebook",
                 "Enable or disable Facebook comment box", "", "Enabled Facebook Comment Box", true,
                 Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                 ValueType.Single, CultureIDs.English,
                 "FacebookCommentAPIKey", "", "System", "Facebook",
                 "Facebook unique identifier for the application.<br/>Get this key in \"Setting\" section on Facebook developers page.",
                 "", "App ID/API key", true, Configuration.ConfigurationType.TextBox,
                 "", "", "", "FacebookCommentEnabled", "", "", "Required", Store.Null.StoreID );

            CreateConfigConditionally(
               ValueType.Single, CultureIDs.English,
               "FacebookCommentNumberOfPosts", "10", "System", "Facebook", "The number of posts to display by default.",
               "", "Number of posts", true, Configuration.ConfigurationType.TextBox,
               "", "", "", "FacebookCommentEnabled", "", "", "Required|Integer", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "BlogCommentEnabled", "False", "System", "Blog",
                "Enable or disable blog comment box", "", "Enabled Blog Comment Box", true,
                Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "BlogCommentsPerPage", "10", "System", "Blog", "The number of blog comment per page to display.",
                "", "Number of blog comment per page", true, Configuration.ConfigurationType.TextBox,
                "", "", "", "BlogCommentEnabled", "", "", "Required|Integer", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.Single, CultureIDs.English,
                "BlogCommentsSortOrder", "Last to First", "System", "Blog", "The display order type of blog comment.",
                "", "Blog comment display order", true, Configuration.ConfigurationType.DropDown,
                "Last to First|First to Last", "Last to First|First to Last", "", "BlogCommentEnabled", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                 ValueType.Single, CultureIDs.English,
                 "DisplayArchivesEnabled", "False", "System", "Blog",
                 "Display or hide archive box", "", "Enabled Archive box", true,
                 Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                 ValueType.Single, CultureIDs.English,
                 "BlogCountInCategoryBox", "False", "System", "Blog",
                 "Display or hide number of blog count in Blog Category box", "", "Display Blog Count in Blog Category box", true,
                 Configuration.ConfigurationType.DropDown, "True|False", "Yes|No", "", "", "", "", "", Store.Null.StoreID );
        }

        private static void CreateSeoConfiguration()
        {
            CreateConfigConditionally(
               ValueType.MultiCulture, CultureIDs.English,
               "DefaultProductPageTitle", "[ProductName] - [SiteName]", "System", "Product",
               "This setting will be shown on product page title bar.",
               "", "Default Product Page Title", true, Configuration.ConfigurationType.TextBox,
               "", "", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
               ValueType.MultiCulture, CultureIDs.English,
               "DefaultProductMetaKeyword", "[ProductName]", "System", "Product",
               "This setting will be put in HTML &lt;meta&gt; tag, which will be used <br /> by search engines such as Google to describe your page",
               "", "Default Product Meta Keyword", true, Configuration.ConfigurationType.TextBox,
               "", "", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.MultiCulture, CultureIDs.English,
                "DefaultProductMetaDescription", "[ProductShortDescription]", "System", "Product",
                "This setting will be put in HTML &lt;meta&gt; tag, which will be used <br /> by search engines such as Google to describe your page",
                "", "Default Product Meta Description", true, Configuration.ConfigurationType.TextBox,
                "", "", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.MultiCulture, CultureIDs.English,
                "DefaultCategoryPageTitle", "[CatgoryParentList] [CategoryName] - [SiteName]", "System", "Category",
                "This setting will be shown on category page title bar.",
                "", "Default Category Page Title", true, Configuration.ConfigurationType.TextBox,
                "", "", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.MultiCulture, CultureIDs.English,
                "DefaultCategoryMetaKeyword", "[CategoryName]", "System", "Category",
                "This setting will be put in HTML &lt;meta&gt; tag, which will be used <br /> by search engines such as Google to describe your page",
                "", "Default Category Meta Keyword", true, Configuration.ConfigurationType.TextBox,
                "", "", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.MultiCulture, CultureIDs.English,
                "DefaultCategoryMetaDescription", "[CategoryDescription]", "System", "Category",
                "This setting will be put in HTML &lt;meta&gt; tag, which will be used <br /> by search engines such as Google to describe your page",
                "", "Default Category Meta Description", true, Configuration.ConfigurationType.TextBox,
                "", "", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.MultiCulture, CultureIDs.English,
                "DefaultDepartmentPageTitle", "[DepartmentParentList] [DepartmentName] - [SiteName]", "System", "Department",
                "This setting will be shown on department page title bar.",
                "", "Default Department Page Title", true, Configuration.ConfigurationType.TextBox,
                "", "", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.MultiCulture, CultureIDs.English,
                "DefaultDepartmentMetaKeyword", "[DepartmentName]", "System", "Department",
                "This setting will be put in HTML &lt;meta&gt; tag, which will be used <br /> by search engines such as Google to describe your page",
                "", "Default Department Meta Keyword", true, Configuration.ConfigurationType.TextBox,
                "", "", "", "", "", "", "", Store.Null.StoreID );

            CreateConfigConditionally(
                ValueType.MultiCulture, CultureIDs.English,
                "DefaultDepartmentMetaDescription", "[DepartmentDescription]", "System", "Department",
                "This setting will be put in HTML &lt;meta&gt; tag, which will be used <br /> by search engines such as Google to describe your page",
                "", "Default Department Meta Description", true, Configuration.ConfigurationType.TextBox,
                "", "", "", "", "", "", "", Store.Null.StoreID );
        }

        private static void ResetCompanyDetails()
        {
            Culture cultureEnglish = DataAccessContext.CultureRepository.GetOne( CultureIDs.English );
            Culture cultureThai = DataAccessContext.CultureRepository.GetOne( CultureIDs.Thai );

            DataAccessContext.ConfigurationRepository.UpdateValue( cultureEnglish,
                DataAccessContext.Configurations["Title"], "Website title" );
            DataAccessContext.ConfigurationRepository.UpdateValue( cultureThai,
                DataAccessContext.Configurations["Title"], "ชื่อเว็บไซต์" );
            DataAccessContext.ConfigurationRepository.UpdateValue( cultureEnglish,
                DataAccessContext.Configurations["CompanyName"], "VevoCart" );
            DataAccessContext.ConfigurationRepository.UpdateValue( cultureThai,
                DataAccessContext.Configurations["CompanyName"], "วีโวคาร์ต" );
            DataAccessContext.ConfigurationRepository.UpdateValue(
                DataAccessContext.Configurations["CompanyEmail"], "companyemail@127.0.0.1" );
            DataAccessContext.ConfigurationRepository.UpdateValue( cultureEnglish,
                DataAccessContext.Configurations["CompanyAddress"], "Company address..." );
            DataAccessContext.ConfigurationRepository.UpdateValue( cultureThai,
                DataAccessContext.Configurations["CompanyAddress"], "ที่อยู่บริษัท..." );
            DataAccessContext.ConfigurationRepository.UpdateValue( cultureEnglish,
                DataAccessContext.Configurations["CompanyCity"], "City..." );
            DataAccessContext.ConfigurationRepository.UpdateValue( cultureThai,
                DataAccessContext.Configurations["CompanyCity"], "จังหวัด..." );
            DataAccessContext.ConfigurationRepository.UpdateValue( cultureEnglish,
                DataAccessContext.Configurations["CompanyState"], "State..." );
            DataAccessContext.ConfigurationRepository.UpdateValue( cultureThai,
                DataAccessContext.Configurations["CompanyState"], "รํฐ..." );
            DataAccessContext.ConfigurationRepository.UpdateValue(
                DataAccessContext.Configurations["CompanyZip"], "00001" );
            DataAccessContext.ConfigurationRepository.UpdateValue( cultureEnglish,
                DataAccessContext.Configurations["CompanyCountry"], "Country..." );
            DataAccessContext.ConfigurationRepository.UpdateValue( cultureThai,
                DataAccessContext.Configurations["CompanyCountry"], "ประเทศ..." );
            DataAccessContext.ConfigurationRepository.UpdateValue(
                DataAccessContext.Configurations["CompanyPhone"], "xxx-xxx-xxxx" );
            DataAccessContext.ConfigurationRepository.UpdateValue(
                DataAccessContext.Configurations["CompanyFax"], "xxx-xxx-xxxx" );
        }

        private static void ResetPaymentDetails()
        {
            DataAccessContext.ConfigurationRepository.UpdateValue(
                DataAccessContext.Configurations["PaymentCurrency"], "USD" );
            DataAccessContext.ConfigurationRepository.UpdateValue(
                DataAccessContext.Configurations["UseCustomTimeZone"], "False" );
            DataAccessContext.ConfigurationRepository.UpdateValue(
                DataAccessContext.Configurations["CustomTimeZone"], "0.0" );

            // PayPal Pro
            DataAccessContext.ConfigurationRepository.UpdateValue(
                DataAccessContext.Configurations["PayPalAPIUserName"], "" );
            DataAccessContext.ConfigurationRepository.UpdateValue(
                DataAccessContext.Configurations["PayPalAPIPassword"], "" );
            DataAccessContext.ConfigurationRepository.UpdateValue(
                DataAccessContext.Configurations["PayPalAPISignature"], "" );

            // KPayment
            DataAccessContext.ConfigurationRepository.UpdateValue(
                DataAccessContext.Configurations["KPaymentMerchantID"], "" );
            DataAccessContext.ConfigurationRepository.UpdateValue(
                DataAccessContext.Configurations["KPaymentTerm"], "" );
            DataAccessContext.ConfigurationRepository.UpdateValue(
                DataAccessContext.Configurations["KPaymentUrl"], "" );
            DataAccessContext.ConfigurationRepository.UpdateValue(
                DataAccessContext.Configurations["KPaymentRequestCardType"], "True" );

            // PayPal
            DataAccessContext.ConfigurationRepository.UpdateValue(
                DataAccessContext.Configurations["PaymentByPayPalEmail"], "" );
            DataAccessContext.ConfigurationRepository.UpdateValue(
                DataAccessContext.Configurations["PaymentByPayPalEnvironment"], "" );

            // PaySbuy
            DataAccessContext.ConfigurationRepository.UpdateValue(
                DataAccessContext.Configurations["PaymentByPaySbuyEmail"], "" );

            // Google Checkout
            DataAccessContext.ConfigurationRepository.UpdateValue(
                DataAccessContext.Configurations["GCheckoutChargeAuto"], "True" );

            // 2Checkout
            DataAccessContext.ConfigurationRepository.UpdateValue(
                DataAccessContext.Configurations["2COMerchantAccount"], "" );

            // Custom
            DataAccessContext.ConfigurationRepository.UpdateValue(
                DataAccessContext.Configurations["PaymentByCustomList"], "Check,COD" );

            // PayFlow Pro
            DataAccessContext.ConfigurationRepository.UpdateValue(
                DataAccessContext.Configurations["PayflowProUser"], "" );
            DataAccessContext.ConfigurationRepository.UpdateValue(
                DataAccessContext.Configurations["PayflowProVender"], "" );
            DataAccessContext.ConfigurationRepository.UpdateValue(
                DataAccessContext.Configurations["PayflowProPartner"], "" );
            DataAccessContext.ConfigurationRepository.UpdateValue(
                DataAccessContext.Configurations["PayflowProPassword"], "" );
            DataAccessContext.ConfigurationRepository.UpdateValue(
                DataAccessContext.Configurations["PayflowProTest"], "True" );
        }

        private static void ResetStoreDisplay()
        {
            DataAccessContext.ConfigurationRepository.UpdateValue(
                DataAccessContext.Configurations["RandomProductShow"], "4" );
            DataAccessContext.ConfigurationRepository.UpdateValue(
                DataAccessContext.Configurations["IsCatalogMode"], "False" );
            DataAccessContext.ConfigurationRepository.UpdateValue(
                DataAccessContext.Configurations["WholesaleMode"], "0" );
            DataAccessContext.ConfigurationRepository.UpdateValue(
                DataAccessContext.Configurations["RetailPriceMode"], "True" );
            DataAccessContext.ConfigurationRepository.UpdateValue(
                DataAccessContext.Configurations["ShowSkuMode"], "False" );
            DataAccessContext.ConfigurationRepository.UpdateValue(
                DataAccessContext.Configurations["LogoImage"], "Images/Configuration/logo.gif" );
            DataAccessContext.ConfigurationRepository.UpdateValue(
                DataAccessContext.Configurations["ProductItemsPerPage"], "3,1,5,7" );
            DataAccessContext.ConfigurationRepository.UpdateValue(
                DataAccessContext.Configurations["CategoryItemsPerPage"], "4,2,6,8" );
            DataAccessContext.ConfigurationRepository.UpdateValue(
                DataAccessContext.Configurations["DepartmentItemsPerPage"], "4,2,6,8" );
            DataAccessContext.ConfigurationRepository.UpdateValue(
                DataAccessContext.Configurations["TellAFriendEnabled"], "True" );
            DataAccessContext.ConfigurationRepository.UpdateValue(
                DataAccessContext.Configurations["ManufacturerItemsPerPage"], "4,2,6,8" );
        }

        private static void SetUpTestValuesNoDelete( ConfigurationCollection CustomConfigurations )
        {
            using (DataTransactionScope transaction = new DataTransactionScope())
            {
                CreateMerchantDetails();
                CreateMailServerConfiguration();
                CreateDisplayConfiguration();
                CreateLayoutConfiguration();
                CreateCacheConfiguration();
                CreatePaymentConfiguration();
                CreateShippingConfiguration();
                CreateTaxConfiguration();
                CreateCompanyConfiguration();

                CreateGiftCertificateConfiguration();
                CreateProductImageConfiguration();
                CreateTrackingUrl();
                CreateGoogleAnalytics();
                CreateEmailNotification();

                CreateMiscConfiguration();
                CreateAffiliateConfiguration();

                CreateQuickBooksConfiguration();
                CreateWebServiceConfiguration();

                CreateeBayConfiguration();

                CreareFacebookConfiguration();

                CreateBlogConfiguration();
                CreateSingleCustomConfiguration( CustomConfigurations );

                CreatePointSystemConfiguration();
                CreateSeoConfiguration();

                transaction.Complete();
            }

            SystemConfig.Load();
        }

        #endregion


        #region Public Methods

        public static bool ContainsKey( string configName )
        {
            if (GetConfigTable( NeutralCultureID ) != null)
            {
                foreach (Configuration config in GetConfigTable( NeutralCultureID ))
                    if (config.Name == configName)
                        return true;
            }
            return false;
        }

        public static void Load()
        {
            WebUtilities.ClearCacheWithPrefix( CachePrefix );
            _configurations = DataAccessContext.Configurations;
        }

        public static void SetUpTestValues( ConfigurationCollection CustomConfigurations )
        {
            DataAccessContext.ConfigurationRepository.DeleteAll();

            Load();

            SetUpTestValuesNoDelete( CustomConfigurations );
        }

        public static void ResetToDefaultValues()
        {
            ResetCompanyDetails();
            ResetPaymentDetails();
            ResetStoreDisplay();

            SystemConfig.Load();
        }

        public static void UpdateNewConfigValue( ConfigurationCollection CustomConfigurations )
        {
            Load();

            DataTable tableConfiguration = DataAccess.ExecuteSelect( "SELECT * FROM Configuration" );
            DataTable tableConfigurationValue = DataAccess.ExecuteSelect( "SELECT * FROM ConfigurationValue" );

            SetUpTestValuesNoDelete( CustomConfigurations );

            DataTable tableCurrent = DataAccess.ExecuteSelect( "SELECT * FROM Configuration" );

            foreach (DataRow rowCurrent in tableCurrent.Rows)
            {
                foreach (DataRow row in tableConfiguration.Rows)
                {
                    if (String.Compare( rowCurrent["Name"].ToString(), row["Name"].ToString(), true ) == 0)
                    {
                        string configID = row["ConfigID"].ToString();

                        DataRow[] rowConfigValue = tableConfigurationValue.Select( "ConfigID = " + configID );

                        foreach (DataRow rowConfigValueOld in rowConfigValue)
                        {
                            if (rowConfigValueOld["CultureID"].ToString() == "0")
                            {
                                DataAccessContext.ConfigurationRepository.UpdateValue(
                                    DataAccessContext.Configurations[rowCurrent["Name"].ToString()],
                                    rowConfigValueOld["ItemValue"].ToString() );
                            }
                            else
                            {
                                Culture culture = DataAccessContext.CultureRepository.GetOne(
                                    rowConfigValueOld["CultureID"].ToString() );
                                DataAccessContext.ConfigurationRepository.UpdateValue(
                                    culture,
                                    DataAccessContext.Configurations[rowCurrent["Name"].ToString()],
                                    rowConfigValueOld["ItemValue"].ToString() );
                            }
                        }
                        break;
                    }
                }
            }

            Load();
        }

        #endregion

    }
}
